<?php
/**------------------------------------------------
*
* Rooty, 2018 <rooty@rooty.me>
*
*
* This software is protected by copyright, please
* read the file COPYRIGHT.
* This program is distributed in the hope that it
* will be useful, but without any warranty; without
* even the implied warranty of merchantability or
* fitness for a particular purpose. Please
* read the file LICENCE.
*
* Fichier GroupManager.php
*
* Ce fichier contient la classe GroupManager
*
* @author Rooty <www.rooty.me|rooty@rooty.me>
* @link www.rooty.me
* @since 2004/06/05
* @version 0.3
* @package system_data
* @subpackage Group
* @copyright Copyright &copy; 2009-2018, Rooty
*/

#####################################################################################################
################################# Parametrage
#####################################################################################################
/**
* declaration du system... si cette variable n'est pas définie, les fichier inclus ne marche pas...
* cette variable est déclarée sur la page d'execution du script.
* <p> if ( !defined('SYSTEM_IN') )
* {
* die("Hacking attempt");
* }</p>
*/
if ( !defined('SYSTEM_IN') )
{
 die("Hacking attempt");
}

/**
* Appel à la classe Group...
*/
require ($CONF_LIB_PATH."lib/system/system_data/group/group.php");

/**
* Classe GroupManager
*
* <P>Classe de gestion des instances de Groups <br>
*   (permet de fabriquer, detruire, mettre à jour des objet Groups)<br>
* Cette classe se sert des ressources à sa disposition (dans ./ressource)<br>
* Les Classes de ressource doivent avoir toutes les methodes correspondantes <br>
* aux methodes de la classe intitulés sourceXXX</P>
*
* <p>Est configuré dans data_acces.php : <br>
* - La Source d'information (Db)<br>
* l'objet ressource se sert lui-même des classes d'accés aux données(lib/data_source/...)<br>
* </p>
* @package system_data
* @subpackage Group
*/
class GroupManager extends Manager
{

	//
	// Constructor
	//
/**
* Constructeur de la classe GroupManager PHP5
*
* @access public
*/
	function __construct()
	{
	}


###########################################################################
#### Méthodes abstraites
###########################################################################

/**
* doLoadFromId : charge le Groupe
*
* <P>Chargement depuis la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accés aux données</P>
* @param entier identifiant de la Groupe
* @access public
* @abstract
* @return tableau tableau des éléments d'un groupe
*/
	function doLoadFromId($id)
	{
		return array();
	}

/**
* doLoadFromIdPere : charge le(s) Groupe(s) depuis un id pere
*
* <P>Chargement depuis la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accés aux données</P>
* @param entier identifiant de la Groupe
* @access public
* @abstract
* @return tableau tableau des éléments d'un groupe
*/
	function doLoadFromIdPere($id)
	{
		return array();
	}
/**
* doLoadFromIdPere : charge le(s) Groupe(s) depuis un id pere
*
* <P>Chargement depuis la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accés aux données</P>
* @param entier identifiant de la Groupe
* @access public
* @abstract
* @return tableau tableau des éléments d'un groupe
*/
	function doLoadFromNodeId($id)
	{
		return array();
	}

/**
* doUpdate : Update du Groupe
*
* <P>Insertion dans la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accés aux données</P>
* @param entier identifiant du Groupe père
* @param chaine libelle du Groupe
* @param chaine icone du Groupe
* @access public
* @abstract
* @return entier
*/
	function doUpdate($id, $idPere, $libelle, $icone)
	{
		return 0;	/* entier */
	}

/**
* doInsert : Insert le Groupe
*
* <P>Insertion dans la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accés aux données</P>
* @param entier identifiant du Groupe père
* @param chaine libelle du Groupe
* @param chaine icone du Groupe
* @access public
* @abstract
* @return entier
*/
	function doInsert($idPere, $libelle, $icone)
	{
		return true;
	}

/**
* doDelete : Detruit le Groupe
*
* <P>Suppression de l'objet à partir de son identifiant et dans la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accés aux données</P>
* @param entier identifiant de la Groupe
* @access public
* @abstract
* @return booleen
*/
	function doDelete($id)
	{
		return true;
	}


###########################################################################
#### Méthodes privees
###########################################################################

/**
* sourceLoadFromId: charge à partir d'un identifiant
*
* <p>Permet le récupération des infos d'un objet Group à partir de son identifiant</p>
* <P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
* <p>Retourne un tableau contenant les infos de l'objet<br>
* <br>ou faux si n'existe pas</p>
* @param identifiant du Groupe
* @access private
* @return tableau
*/
	function sourceLoadFromId($id)
	{
		$tab=$this->doLoadFromId($id);
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if (!is_array($tab))
		{
			/* Erreur */
			$systemError=1;
			$classe="Group";
			$message="Erreur dans GroupManager";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}else{
			if ((!Is_numeric($tab["id"])) || (!Is_numeric($tab["idpere"])))
			{
				/* Erreur */
				$systemError=1;
				$classe="Group";
				$message="Erreur dans GroupManager";
				addError($systemError,$classe,$message, __line__, __file__);
				return array();
			}else{
				return $tab;
			}
		}
	}

/**
* sourceInsert: Insert le Groupe
*
* <p>Insertion de l'objet Groupe dans la source de données<br>
* indifférement du type de cette source</p>
* <P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
* <p>Retourne L'identifiant de l'objet inséré</p>
* @param entier identifiant du Groupe père
* @param chaine libelle du Groupe
* @param chaine icone du Groupe
* @access private
* @return entier
*/
	function sourceInsert($idPere, $libelle, $icone)
	{
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if (!is_numeric($idPere))
		{
			/* Erreur */
			$systemError=1;
			$classe="Group";
			$message="Erreur dans GroupManager";
			addError($systemError,$classe,$message, __line__, __file__);
			return false;
		}
		return $this->doInsert($idPere, $libelle, $icone);
	}

/**
* sourceUpdate: Met à jour le Groupe
*
* <P>Mise à jour de l'objet indifferemment de la source de données</P>
* <P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
* @param entier identifiant du Groupe père
* @param chaine libelle du Groupe
* @param chaine icone du Groupe
* @access private
* @return booleen
*/
	function sourceUpdate($id,$idPere, $libelle, $icone)
	{
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if (!Is_numeric($id) || !is_numeric($idPere))
		{
			/* Erreur */
			$systemError=1;
			$classe="Group";
			$message="Erreur dans GroupManager";
			addError($systemError,$classe,$message, __line__, __file__);
			return false;
		}

		return $this->doUpdate($id, $idPere, $libelle, $icone);
	}

/**
* sourceDelete: Detruit le Groupe
*
* <p>Suppression de l'objet à partir de son identifiant</p>
* <P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
* @param entier identifiant de la Groupe
* @access private
* @return booleen
*/
	function sourceDelete($id)
	{
		return $this->doDelete($id);
	}


/**
* sourceLoadFromNodeId: charge à partir d'un identifiant
*
* <p>Permet le récupération des infos d'un objet Group à partir de son identifiant de noeud</p>
* <P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
* <p>Retourne un tableau de tableau contenant les infos des objets</p>
* @param identifiant du Groupe
* @access private
* @return tableau
*/
	function sourceLoadFromNodeId($id)
	{
		$tab=$this->doLoadFromNodeId($id);
		if (is_array($tab))
		{
			return $tab;
		}
		/* Erreur */
		$systemError=1;
		$classe="Group";
		$message="Erreur dans GroupManager";
		addError($systemError,$classe,$message, __line__, __file__);
		return $tab;
	}

/**
* sourceLoadFromIdPere: charge à partir d'un identifiant
*
* <p>Permet le récupération des infos d'un objet Group à partir de son identifiant</p>
* <P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
* <p>Retourne un tableau contenant les infos de l'objet<br>
* <br>ou faux si n'existe pas</p>
* @param identifiant du Groupe
* @access private
* @return tableau
*/
	function sourceLoadFromIdPere($id)
	{
		$tab=$this->doLoadFromIdPere($id);
		if (is_array($tab))
		{
			return $tab;
		}
		/* Erreur */
		$systemError=1;
		$classe="Group";
		$message="Erreur dans GroupManager";
		addError($systemError,$classe,$message, __line__, __file__);
		return $tab;
	}


###########################################################################
#### Méthodes public
###########################################################################

/**
* createNewInstance : créer un objet vierge
*
* @param object objet Group à effacer
* @access public
* @return booleen
*/
	function createNewInstance()
	{
		return new Group();
	}
/**
* createInstance : récupere l'objet avec l'identifiant $id
*
* @param entier identifiant de l'association Group
* @access public
* @return object retourne un objet de type Group
*/
	function createInstance($id)
	{
		$return = new Group();
		if (is_numeric($id))
		{
			/* Récupération des infos */
			$tab=$this->sourceLoadFromId($id);
			if (is_array($tab) && isset($tab["id"]) && is_numeric($tab["id"]))
			{
				/* création et alimentation de l'objet */
				$return->doLoad($tab["id"], $tab["idpere"], $tab["libelle"], $tab["icone"]);
			}else{
				$systemError=3;
				$classe="GroupManager";
				$message="Erreur id inexistant ".$id;
				addError($systemError, $classe, $message, __line__, __file__);
			}
		}else{
			$systemError=3;
			$classe="GroupManager";
			$message="Erreur id invalide ".$id;
			addError($systemError, $classe, $message, __line__, __file__);
		}
		return $return;
	}

/**
* getInstanceFromIdPere : récupere les objets Group ayant pour pere l'id
*
* @param entier identifiant de l'utilisateur
* @access public
* @return tableau tableau d'objets Group
*/
	function getInstanceFromIdPere($id)
	{
		$return = array();		/* Tableau de GroupUserGroup */
		if (is_numeric($id))
		{
			/* Récupération des infos */
			$tab=$this->sourceLoadFromIdPere($id);
			if (is_array($tab))
			{
				/* création et alimentation de l'objet */
				for ($i=0; $i<count($tab); $i++)
				{
					$return[$i]=new Group();
					$return[$i]->doLoad($tab[$i]["id"], $tab[$i]["idpere"], $tab[$i]["libelle"], $tab[$i]["icone"]);
				}
			}else{
				$systemError=3;
				$classe="GroupManager";
				$message="Erreur objet invalide ";
				addError($systemError, $classe, $message, __line__, __file__);
			}
		}else{
			$systemError=3;
			$classe="GroupManager";
			$message="Erreur objet invalide ";
			addError($systemError, $classe, $message, __line__, __file__);
		}
		return $return;
	}

/**
* getInstanceFromNodeId : récupere les objets Group ayant pour node l'id
*
* @param entier identifiant de l'utilisateur
* @access public
* @return tableau tableau d'objets Group
*/
	function getInstanceFromNodeId($id)
	{
		$return = array();		/* Tableau de GroupUserGroup */
		if (is_numeric($id))
		{
			/* Récupération des infos */
			$tab=$this->sourceLoadFromNodeId($id);
			if (is_array($tab))
			{
				/* création et alimentation de l'objet */
				for ($i=0; $i<count($tab); $i++)
				{
					$return[$i]=new Group();
					$return[$i]->doLoad($tab[$i]["id"], $tab[$i]["idpere"], $tab[$i]["libelle"], $tab[$i]["icone"]);
				}
			}else{
				$systemError=3;
				$classe="GroupManager";
				$message="Erreur objet invalide ";
				addError($systemError, $classe, $message, __line__, __file__);
			}
		}else{
			$systemError=3;
			$classe="GroupManager";
			$message="Erreur objet invalide ";
			addError($systemError, $classe, $message, __line__, __file__);
		}
		return $return;
	}

/**
* deleteInstance : detruit l'objet physique
* @param object objet Group à effacer
* @access public
* @return object objetGroup mis à jour
*/
	function deleteInstance($obj)
	{
		$return = false;
		if (strtolower(get_class($obj))=="group")
		{
			if($obj->isLoaded()==true)
			{
				/* Récupération des infos */
				$this->CallSystemPlugin("__deleteGroup", $obj);
				$return=$this->sourceDeleteFromId($obj->getId());
				$obj->setId(0);
				return $obj;
			}
		}
		/* Erreur */
		$systemError=3;
		$classe="GroupManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}

/**
* updateInstance : met à jour l'objet
*
* @param object objet Group à modifier
* @access public
* @return object objetGroup mis à jour
*/
	function updateInstance($obj)
	{
		$return = false;
		if ((strtolower(get_class($obj))=="group") && ($obj->isLoaded()==true))
		{
			/* Récupération des infos */
			$id=$this->sourceUpdate($obj->getId(), $obj->getIdPere(), $obj->getXmlLibelle(), $obj->getIcone());
			$this->CallSystemPlugin("__updateGroup", $obj);
			return $obj;
		}
		/* Erreur */
		$systemError=3;
		$classe="GroupManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}
/**
* insertInstance : créer enregistre l'objet
*
* <p>affecte l'id de l'objet si nécessaire</p>
* @param object objet Group à inserer
* @access public
* @return object objetGroup mis à jour
*/
	function insertInstance($obj)
	{
		if ((strtolower(get_class($obj))=="group"))
		{
			if ($obj->isLoaded()==false)
			{
				/* Récupération des infos */
				$id=$this->sourceInsert($obj->getIdPere(), $obj->getXmlLibelle(), $obj->getIcone());
				$obj->setId($id);
				$this->CallSystemPlugin("__insertGroup", $obj);
				return $obj;
			}
		}
		/* Erreur */
		$systemError=3;
		$classe="GroupManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}
/**
* saveInstance : créer enregistre l'objet
*
* @param object objet Group à sauvegarder
* @access public
* @return object objetGroup mis à jour
*/
	function saveInstance($obj)
	{
		if ((strtolower(get_class($obj))==strtolower("group")))
		{
			if ($obj->isLoaded()==false)
			{
				$return=$this->insertInstance($obj);
			}else{
				$return=$this->updateInstance($obj);
			}
			return $return;
		}
		/* Erreur */
		$systemError=3;
		$classe="GroupManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);
		$return=$obj;

		return $return;
	}
}
?>
