<?php

/**------------------------------------------------
*
* Rooty, 2018 <rooty@rooty.me>
*
*
* This software is protected by copyright, please
* read the file COPYRIGHT.
* This program is distributed in the hope that it
* will be useful, but without any warranty; without
* even the implied warranty of merchantability or
* fitness for a particular purpose. Please
* read the file LICENCE.
*
* Fichier GroupManagerDb.php
*
* Ce fichier contient la classe GroupManagerDb
*
* @author Rooty <www.rooty.me|rooty@rooty.me>
* @link www.rooty.me
* @since 2004/04/14
* @version 0.3
* @package system_data
* @subpackage Group
* @copyright Copyright &copy; 2009-2018, Rooty
*/
if ( !defined('SYSTEM_IN') )
{
 die("Hacking attempt");
}

/**
* Classe GroupManagerDb
*
* classe de gestion des Groups pour une do de données database (type gérés par database)<br><br>
* Sont configuré dans config_data_acces.php:<br>
* - La do d'information <br>
*    (actuellement seul DB possible->Pour ajouter une do reproduire GroupGroupManagerDb)<br>
* - Le Nom de la Table<br>
* - La configuration (Paramétrage des dos de do de données) est faite dans config_data_do.php<br>
* - La declaration de la connexion est faite à partir de config_system.php
*
* @package system_data
* @subpackage Group
*/
class GroupManagerDb extends GroupManager
{

/**
* @var chaine
* @access private
* @desc ID de la Group
*/
var $table = "";

/**
* @var array
* @access private
* @desc objet database
*/
var $sqlAttributArray	= array();

/**
* @var object
* @access private
* @desc objet database
*/
var $conn = null;

	//
	// Constructor
	//
/**
* Constructeur de la classe GroupManagerDb PHP4
*
* <p>Initialise la GroupManagerDb</p>
* @access public
*/
	function GroupManagerDb()
	{
		$this->__construct();
	}

/**
* Constructeur de la classe GroupManagerDb PHP5
*
* <p>Initialise la GroupManagerDb</p>
* @access public
*/
	function __construct()
	{
		$this->setTable( DATA_ACCES_TABLE_GROUP );	/* Appel à la constante correspondant */
		$this->initSqlAttribut();			/* initialisation des noms de champs */
		$this->setConn($GLOBALS['SYSTEM_DATABASE_CONN']);
	}

/**
* getTable : recupere le nom de la table utilisée
*
* @access public
* @return chaine
*/
	function getTable()
	{
		return $this->table;
	}

/**
* setTable : recupere le nom de la table utilisée
*
* @access public
* @param chaine nom de la table
* @return chaine
*/
	function setTable($chaine)
	{
		if (!is_string($chaine))
			return false;

		$this->table=$chaine;
		return true;
	}

/**
* getTable : recupere le nom de la table utilisée
*
* @access public
* @return chaine
*/
	function getConn()
	{
		return $this->conn;
	}

/**
* setTable : recupere le nom de la table utilisée
*
* @access public
* @param object objet classe "database"
* @return chaine
*/
	function setConn(&$obj)
	{
		if (!is_object($obj))
			return false;

		$this->conn=&$obj;
		return true;
	}

/**
* doLoadFromId: Charge le Groupe depuis la BD
*
* <p>Retourne un tableau contenant les infos de l'objet</p>
* @access private
* @param entier identifiant du Groupe
* @return tableau
*/
	function doLoadFromId($id)
	{
		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_numrows()==0)
		{
			$systemError=1;
			$classe="Group";
			$message="Erreur du load from id dans l'objet FetchGroupManagerDb LoadFromId, avec l'id=".$id;
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}

		$tab=$this->conn->sql_fetchrow();
		$tab=$this->translateArray($tab);

		# Destruction des éléments
		$this->conn->sql_freeresult();
		return $tab;
	}

/**
* doInsert: Insert le Groupe dans la BD
*
* <p>Insertion dans la Bd</P>
* @param entier identifiant du pére
* @param chaine libelle de la Groupe
* @param chaine icone de la Groupe
* @access private
* @return entier
*/
	function doInsert($idPere, $libelle, $icone)
	{
		$sql="INSERT INTO ".$this->getTable()." ("
			.$this->getSqlName("idpere").", "
			.$this->getSqlName("libelle").", "
			.$this->getSqlName("icone").") VALUES ('".$idPere."', '".$libelle."', '".$icone."' )";

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_affectedrows()==0)
		{
			$systemError=1;
			$classe="Group";
			$message="Erreur d'INSERTION dans FetchGroupManagerDb avec le libelle".$libelle;
			addError($systemError,$classe,$message, __line__, __file__);
			return 0;
		}
		$retour=$this->conn->sql_nextid();
		return $retour;
	}

/**
* doUpdate : Modifie le Groupe dans la BD
*
* <p>Mise à jour de la Group</P>
* @param entier identifiant
* @param entier identifiant du pére
* @param chaine libelle de la Groupe
* @param chaine icone de la Groupe
* @access private
* @return booleen
*/
	function doUpdate($id, $idPere, $libelle, $icone)
	{
		$sql="UPDATE ".$this->getTable()." SET "
			.$this->getSqlName("id")."='".$id."', "
			.$this->getSqlName("idpere")."='".$idPere."', "
			.$this->getSqlName("libelle")."='".$libelle."', "
			.$this->getSqlName("icone")."='".$icone
			."' WHERE ".$this->getSqlName("id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);
		$retour=$id;
		return $retour;
	}

/**
* doDelete : Detruit le Groupe dans la BD
*
* <p>Suppression de la Groupe à partir de son identifiant</p>
* @param entier identifiant du Groupe
* @access private
* @return booleen
*/
	function doDelete($id)
	{
		$sql="DELETE FROM ".$this->getTable()." WHERE ".$this->getSqlName("id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_affectedrows()==0)
		{
			$systemError=1;
			$classe="Group";
			$message="Erreur de SUPPRESSION dans FetchGroupManagerDb avec l'id ".$id;
			addError($systemError,$classe,$message, __line__, __file__);
			return false;
		}
		return true;
	}

/**
* doLoadFromIdPere: Charge les Groupe depuis la BD à partir d'un idpere
*
* <p>Retourne un tableau contenant les infos de l'objet
* <br>ou faux si n'existe pas;<br>
* !!! id doit être un entier</P>
* @access private
* @param entier identifiant de la Group
* @return tableau
*/
	function doLoadFromIdPere($id)
	{
		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("idpere")."=".$id." ORDER BY ".$this->getSqlName("libelle");

		# Requete
		$result=$this->conn->sql_query($sql);
		$tab=array();

		for ($i=0; $i<$this->conn->sql_numrows();$i++)
		{
			$tab[$i]=$this->conn->sql_fetchrow();
			$tab[$i]=$this->translateArray($tab[$i]);
		}

		# Destruction des éléments
		$this->conn->sql_freeresult();
		return $tab;
	}

	//////////////////////////////////////////////////////////////////////////
	//
	// Utilitaires pour la gestion des compatibilités BD
	//
	/////////////////////////////////////////////////////////////////////////
/**
* translateKey : change les cles du tableau resultant d'une requete en tableau de données pour l'objet
*
* <p>Supprime le nom de la table dans les noms de champs renvoy?s par la BD<br/>
* garde la compatibilité avec les version précédentes</p>
* @param array tableau sql
* @access private
* @return array tableau des attributs
*/
	function translateArray($sqlArray)
	{
		/* Cas nouvelle BD systeme */
		$result["id"]				=$sqlArray[$this->getSqlName('id')];
		$result["idpere"]			=$sqlArray[$this->getSqlName("idpere")];
		$result["libelle"]			=$sqlArray[$this->getSqlName("libelle")];
		$result["icone"]			=$sqlArray[$this->getSqlName("icone")];
		return $result;
	}

/**
* initSqlAttributName : recupere le nom d'un attribut a partir d'une cle
*
* <p>En fonction de la version sql, on trouvera ici la correspondance entre le nom attribut de l'objet et son nom en BD<br/>
* cette methode permet de garder la compatibilité avec les version précédentes</p>
* @param chaine nom de l'attribut recherche
* @access private
* @return booleen
*/
	function initSqlAttribut(){

		if(defined('DATA_ACCES_TABLE_VERSION'))
		{
			if( DATA_ACCES_TABLE_VERSION == 1)
			{
				$this->sqlAttributArray["id"]				="group_id";
				$this->sqlAttributArray["idpere"]			="group_group_id";
				$this->sqlAttributArray["libelle"]			="group_libelle";
				$this->sqlAttributArray["icone"]			="group_icone";
				return true;
			}
		}
		$this->sqlAttributArray["id"]				="id";
		$this->sqlAttributArray["idpere"]			="idpere";
		$this->sqlAttributArray["libelle"]			="libelle";
		$this->sqlAttributArray["icone"]			="icone";
		return true;
	}

/**
* getSqlName : recupere le nom du champ a partir d'une cle
*
* <p>En fonction de la version sql, on trouvera ici la correspondance entre le nom attribut de l'objet et son nom en BD<br/>
* Cette methode permet de garder la compatibilite avec les version précédentes<br/>
* Elle s'appuie sur le tableau associatif $this->sqlAttributArray genere par initSqlAttributArray</p>
* @param chaine nom de l'attribut recherche
* @access private
* @return chaine nom du champ sql
*/
	function getSqlName($attribut)
	{
		return ( (isset($this->sqlAttributArray[$attribut]))?$this->sqlAttributArray[$attribut]:$attribut );
	}
}
?>
