<?php

/**------------------------------------------------
*
* Rooty, 2018 <rooty@rooty.me>
*
*
* This software is protected by copyright, please
* read the file COPYRIGHT.
* This program is distributed in the hope that it
* will be useful, but without any warranty; without
* even the implied warranty of merchantability or
* fitness for a particular purpose. Please
* read the file LICENCE.
*
* Fichier GroupUserManager.php
*
* Ce fichier contient la classe GroupUserManager
*
* @author Rooty <www.rooty.me|rooty@rooty.me>
* @link www.rooty.me
* @since 2004/06/05
* @version 0.3
* @package system_data
* @subpackage GroupUser
* @copyright Copyright &copy; 2009-2018, Rooty
*/

####################################################################################################
################################# Parametrage
#####################################################################################################

/**
* declaration du system... si cette variable n'est pas définie, les fichier inclus ne marche pas...
* cette variable est déclarée sur la page d'execution du script.
* <p> if ( !defined('SYSTEM_IN') )
* {
* die("Hacking attempt");
* }</p>
*/
if ( !defined('SYSTEM_IN') )
{
 die("Hacking attempt");
}

/**
* Appel à la classe GroupUser...
*/
require ($CONF_LIB_PATH."lib/system/system_data/groupuser/groupuser.php");

/**
* Classe GroupUserManager
* 
* <p>Classe de gestion des instances de GroupUsers <br>
*   (permet de fabriquer, detruire, mettre à jour des objet GroupUsers)<br>
* Cette classe se sert des ressources à sa disposition (dans ./ressource)<br>
* Les Classes de ressource doivent avoir toutes les methodes correspondantes <br>
* aux methodes de la classe intitulés sourceXXX</p>
* 
* <p>Est configuré dans data_acces.php : <br>
* - La Source d'information (Db)<br>
* l'objet ressource se sert lui-même des classes d'accés aux données(lib/data_source/...)<br>
* </p>
* @package system_data
* @subpackage GroupUser
*/
class GroupUserManager extends Manager
{

	//
	// Constructor
	//
/**
* Constructeur de la classe GroupUserManager PHP5
*
* @access public
*/
	function __construct()
	{
	}


###########################################################################
#### Méthodes abstraites
###########################################################################

/**
* doLoadFromGroupId: Charge la GroupUser depuis la BD
*
* <p>Retourne un tableau contenant les infos de l'objets
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </p>
* @access public
* @abstract
* @param entier identifiant de l'association GroupUser
* @return tableau
*/
	function doLoadFromId($id)
	{
		return array();
	}

/**
* doLoadFromUserId: Charge la GroupUser depuis la BD
*
* <P>Retourne un tableau contenant les infos du GroupUser
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </P>
* @access public
* @param entier identifiant de l'association GroupUser
* @param tableau identifiant des groupes de l'utilisateur
* @abstract
* @return tableau
*/
	function doLoadFromUserId($id)
	{
		return array();
	}

/**
* doLoadFromGroupId: Charge le GroupUser depuis la BD
*
* <P>Retourne un tableau contenant les infos de l'objets
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </P>
* @access public
* @param entier identifiant de l'association GroupUser
* @abstract
* @return tableau
*/
	function doLoadFromGroupId($id)
	{
		return array();
	}


/**
* doInsert: Insert la GroupUser dans la BD
*
* <P>Insertion dans la Bd</P>
* @param entier identifiant de l'utilisateur
* @param entier identifiant du groupe
* @param booleen is node only
* @param booleen is forbidden
* @abstract
* @access public
* @return entier
*/
	function doInsert($userId, $groupId)
	{
		return 0;
	}

/**
* doUpdate:Modifie la GroupUser dans la BD
*
* <P>Mise à jour de la GroupUser</P>
* @param entier identifiant de l'association
* @param entier identifiant de l'utilisateur
* @param entier identifiant du groupe
* @param booleen is node only
* @param booleen is forbidden
* @access public 
* @abstract
* @return booleen
*/
	function doUpdate($id, $userId, $groupId)
	{
		return 0;
	}

/**
* doDelete : Detruit le GroupUser dans la BD
*
* <P>Suppression de l'association Group et User à partir de son identifiant</P>
* @param entier identifiant
* @abstract
* @access public
* @return booleen
*/
	function doDelete($id)
	{
		return true;
	}


###########################################################################
#### Methodes privee
###########################################################################

/**
* sourceLoadFromUserId : charge à partir d'un identifiant utilisateur
*
* <p>Permet le récupération des infos d'un objet GroupUser à partir de son identifiant</p>
* <p>Retourne un tableau contenant les infos de l'objets<br>
* <br>ou faux si n'existe pas
* </p>
* @param identifiant de l'association GroupUser
* @access private
* @return tableau
*/
	function sourceLoadFromId($id)
	{
		$tab=$this->doLoadFromId($id);
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if ((!is_array($tab)) || (count($tab)==0) || (!Is_numeric($tab["id"])))
		{
			$systemError=2;
			$classe="groupuser";
			$message="Erreur de SUPPRESSION dans FetchGroupUserDb avec l'id ".$id;
			addError($systemError, $classe, $message, __line__, __file__);
			return array();
		}
		return $tab;
	}

/**
* sourceLoadFromUserId : charge à partir d'un identifiant utilisateur
*
* <p>Permet le récupération des infos d'un objet GroupUser à partir de son identifiant</p>
* <p>Retourne un tableau contenant les infos de l'objets<br>
* <br>ou faux si n'existe pas
* </p>
* @param identifiant de l'association GroupUser
* @access private
* @return tableau
*/
	function sourceLoadFromUserId($id)
	{
		$tab=$this->doLoadFromUserId($id);
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if ((!is_array($tab)) && (!Is_numeric($tab["id"])))
		{
			$systemError=2;
			$classe="groupuser";
			$message="Erreur de Load dans FetchGroupUserDb";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}
		return $tab;
	}

/**
* sourceLoadFromGroupId : charge à partir d'un identifiant de groupe
*
* <p>Permet le récupération des infos d'un objet GroupUser à partir de son identifiant</p>
* <p>Retourne un tableau contenant les infos de l'objets<br>
* <br>ou faux si n'existe pas
* </p>
* @param identifiant de l'association GroupUser
* @access private
* @return tableau
*/
	function sourceLoadFromGroupId($id)
	{
		$tab=$this->doLoadFromGroupId($id);
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if ((!is_array($tab)) && (!Is_numeric($tab["id"])))
		{
			$systemError=2;
			$classe="groupuser";
			$message="Erreur de Load dans FetchGroupUserDb";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}
		return $tab;
	}

/**
* sourceInsertFromParam : Insert le GroupUser
*
* <p>Insertion de l'objet GroupUser dans la source de données<br>
* indifférement du type de cette source</p>
* <p>Retourne L'identifiant de l'objet insérer</p>
* @param chaine libelle de la GroupUser
* @param chaine repertoire de la GroupUser
* @param chaine icone de la GroupUser
* @param entier état de la GroupUser (active ou inactive)
* @access private
* @return entier
*/
	function sourceInsert($userId, $groupId)
	{
		return $this->doInsert($userId, $groupId);
	}

/**
* sourceUpdateFromParam : Met à jour le GroupUser
*
* <p>Mise à jour de l'objet indifferemment de la source de donnees</p>
* @param entier identifiant
* @param chaine libelle de la GroupUser
* @param chaine repertoire de la GroupUser
* @param chaine icone de la GroupUser
* @param entier état de la GroupUser (active ou inactive)
* @access private
* @return booleen
*/
	function sourceUpdate($id, $userId, $groupId)
	{
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if (!Is_numeric($id))
		{
			$systemError=1;
			$classe="groupuser";
			$message="Erreur de Modification dans GroupUserManager avec l'id ".$id;
			addError($systemError, $classe, $message, __line__, __file__);
			return false;
		}
		return $this->doUpdate($id, $userId, $groupId);
	}

/**
* sourceDeleteFromId : Detruit la GroupUser
*
* <p>Suppression de l'objet à partir de son identifiant</p>
* @param entier identifiant de l'association GroupUser
* @access private
* @return booleen
*/
	function sourceDeleteFromId($id)
	{
		if (!Is_numeric($id))
		{
			$systemError=2;
			$classe="groupuser";
			$message="Erreur de SUPRESSION dans GroupUserManager avec l'id ".$id;
			addError($systemError,$classe,$message, __line__, __file__);

			return false;
		}
		return $this->doDelete($id);
	}


###########################################################################
#### Methodes public
###########################################################################

/**
* createNewInstance : créer un objet vierge
*
* @param object objet GroupUser à effacer
* @access public
* @return booleen
*/
	function createNewInstance()
	{
		return new GroupUser();
	}
/**
* createInstance : récupere l'objet avec l'identifiant $id
*
* @param entier identifiant de l'association GroupUser
* @access public 
* @return object retourne un objet de type GroupUser
*/
	function createInstance($id)
	{
		$return = new GroupUser();
		if (is_numeric($id))
		{
			/* Récupération des infos */
			$tab=$this->sourceLoadFromId($id);
			if (is_array($tab) && isset($tab["id"]) && is_numeric($tab["id"]))
			{
				/* création et alimentation de l'objet */
				$return->doLoad($tab["id"], $tab["user_id"], $tab["group_id"]);
			}else{
				$systemError=3;
				$classe="GroupUserManager";
				$message="Erreur id inexistant ".$id;
				addError($systemError, $classe, $message, __line__, __file__);
			}
		}else{
			$systemError=3;
			$classe="GroupUserManager";
			$message="Erreur id invalide ".$id;
			addError($systemError, $classe, $message, __line__, __file__);
		}
		return $return;
	}
/**
* deleteInstance : detruit l'objet physique
*
* @param object objet GroupUser à effacer
* @access public
* @return object objetGroupUser mis à jour
*/
	function deleteInstance($obj)
	{
		$return = false;
		if ((strtolower(get_class($obj))=="groupuser") )
		{
			if($obj->isLoaded()==true)
			{
				/* Récupération des infos */
				$this->CallSystemPlugin("__deleteGroupUser", $obj);
				$return=$this->sourceDeleteFromId($obj->getId());
				$obj->setId(0);
				return $obj;
			}
		}
		/* Erreur */
		$systemError=3;
		$classe="GroupUserManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}


/**
* updateInstance : met à jour l'objet
*
* @param object objet GroupUser à modifier
* @access public
* @return object objetGroupUser mis à jour
*/
	function updateInstance($obj)
	{
		$return = false;
		if ((strtolower(get_class($obj))=="groupuser") && ($obj->isLoaded()==true))
		{
			/* Récupération des infos */
			$id=$this->sourceUpdate($obj->getId(), $obj->getUserId(), $obj->getGroupId());
			$this->CallSystemPlugin("__updateGroupUser", $obj);
			return $obj;
		}
		/* Erreur */
		$systemError=3;
		$classe="GroupUserManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}
/**
* insertInstance : créer enregistre l'objet
*
* <p>affecte l'id de l'objet si nécessaire</p>
* @param object objet GroupUser à inserer
* @access public
* @return object objetGroupUser mis à jour
*/
	function insertInstance($obj)
	{
		if ((strtolower(get_class($obj))=="groupuser"))
		{
			if ($obj->isLoaded()==false)
			{
				/* Récupération des infos */
				$id=$this->sourceInsert($obj->getUserId(), $obj->getGroupId());
				$obj->setId($id);
				$this->CallSystemPlugin("__insertGroupUser", $obj);
				return $obj;
			}
		}
		/* Erreur */
		$systemError=3;
		$classe="GroupUserManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}
/**
* saveInstance : créer enregistre l'objet
*
* @param object objet GroupUser à sauvegarder
* @access public
* @return object objetGroupUser mis à jour
*/
	function saveInstance($obj)
	{
		if ((strtolower(get_class($obj))=="groupuser"))
		{
			if ($obj->isLoaded()==false)
			{
				$return=$this->insertInstance($obj);
			}else{
				$return=$this->updateInstance($obj);
			}
			return $return;
		}
		/* Erreur */
		$systemError=3;
		$classe="GroupUserManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);
		$return=$obj;

		return $return;
	}

/**
* getInstanceFromUserId : récupere les objets GroupUser de l'utilisateur($id) ayant pour groupe (tableau de groupe $groupe)
*
* @param entier identifiant de l'utilisateur
* @param tableau tableau des groupes associés à l'utilisateur
* @access public
* @return tableau tableau d'objets GroupUser
*/
	function getInstanceFromUserId($id)
	{
		$return = array();		/* Tableau de NodeUserGroup */
		if (is_numeric($id))
		{
			/* Récupération des infos */
			$tab=$this->sourceLoadFromUserId($id);
			if (is_array($tab))
			{
				/* création et alimentation de l'objet */
				for ($i=0; $i<count($tab); $i++)
				{
					$return[$i]=new GroupUser();
					$return[$i]->doLoad($tab[$i]["id"], $tab[$i]["user_id"], $tab[$i]["group_id"]);
				}
			}else{
				$systemError=3;
				$classe="GroupUserManager";
				$message="Erreur objet invalide ";
				addError($systemError, $classe, $message, __line__, __file__);
			}
		}else{
			$systemError=3;
			$classe="GroupUserManager";
			$message="Erreur objet invalide ";
			addError($systemError, $classe, $message, __line__, __file__);
		}
		return $return;
	}

/**
* getInstanceFromGroupId : récupere les objets GroupUser de l'utilisateur($id) ayant pour groupe (tableau de groupe $groupe)
*
* @param entier identifiant du groupe
* @access public
* @return tableau tableau d'objets GroupUser
*/
	function getInstanceFromGroupId($id)
	{
		$return = array();		/* Tableau de NodeUserGroup */
		if (is_numeric($id))
		{
			/* Récupération des infos */
			$tab=$this->sourceLoadFromGroupId($id);
			if (is_array($tab))
			{
				/* création et alimentation du tableau */
				for ($i=0; $i<count($tab); $i++)
				{
					$return[$i]=new GroupUser();
					$return[$i]->doLoad($tab[$i]["id"], $tab[$i]["user_id"], $tab[$i]["group_id"]);
				}
			}else{
				$systemError=3;
				$classe="GroupUserManager";
				$message="Erreur objet invalide ";
				addError($systemError, $classe, $message, __line__, __file__);
			}
		}else{
			$systemError=3;
			$classe="GroupUserManager";
			$message="Erreur objet invalide ";
			addError($systemError, $classe, $message, __line__, __file__);
		}
		return $return;
	}
}
?>
