<?php

/**------------------------------------------------
*
* Rooty, 2018 <rooty@rooty.me>
*
*
* This software is protected by copyright, please
* read the file COPYRIGHT.
* This program is distributed in the hope that it
* will be useful, but without any warranty; without
* even the implied warranty of merchantability or
* fitness for a particular purpose. Please
* read the file LICENCE.
*
* Fichier GroupUserManagerDb.php
*
* Ce fichier contient la classe GroupUserManagerDb
*
* @author Rooty <www.rooty.me|rooty@rooty.me>
* @link www.rooty.me
* @since 2004/04/14
* @version 0.3
* @package system_data
* @subpackage GroupUser
* @copyright Copyright &copy; 2009-2018, Rooty
*/

#####################################################################################################
################################# Parametrage
#####################################################################################################
/**
* declaration du system... si cette variable n'est pas définie, les fichier inclus ne marche pas...
* cette variable est déclarée sur la page d'execution du script.
* <p> if ( !defined('SYSTEM_IN') )
* {
* die("Hacking attempt");
* }</p>
*/
if ( !defined('SYSTEM_IN') )
{
 die("Hacking attempt");
}

/**
* Classe GroupUserManagerDb
*
* classe de gestion des GroupUsers pour une do de données database (type gérés par database)<br><br>
* Sont configuré dans config_data_acces.php:<br>
* - La do d'information <br>
*    (actuellement seul DB possible->Pour ajouter une do reproduire NodeGroupUserManagerDb)<br>
* - Le Nom de la Table<br>
* - La configuration (Paramétrage des dos de do de données) est faite dans config_data_do.php<br>
* - La declaration de la connexion est faite à partir de config_system.php
*
* @package system_data
* @subpackage GroupUser
*/
class GroupUserManagerDb extends GroupUserManager
{

/**
* @var chaine
* @access private
* @desc ID de la GroupUser
*/
var $table		= "";

/**
* @var array
* @access private
* @desc objet database
*/
var $sqlAttributArray	= array();

/**
* @var object
* @access private
* @desc objet database
*/
var $conn		= null;

	//
	// Constructor
	//

/**
* Constructeur de la classe GroupUserManagerDb (PHP4)
*
* <p>Initialise la GroupUserManagerDb</p>
* @access public
*/
	function GroupUserManagerDb()
	{
		$this->__construct();
	}

/**
* Constructeur de la classe GroupUserManagerDb (PHP5)
*
* <p>Initialise la GroupUserManagerDb</p>
* @access public
*/
	function __construct()
	{
		$this->setTable( DATA_ACCES_TABLE_GROUP_USER );			/* Appel à la constant correspondant */
		$this->initSqlAttribut();					/* initialisation des noms de champs */
		$this->setConn($GLOBALS['SYSTEM_DATABASE_CONN']);
	}

/**
* getTable : recupere le nom de la table utilisée
* @access public
* @return chaine 
*/
	function getTable()
	{
		return $this->table;
	}

/**
* setTable : recupere le nom de la table utilisée
* @access public
* @param chaine nom de la table
* @return chaine 
*/
	function setTable($chaine)
	{
		if (!is_string($chaine))
			return false;

		$this->table=$chaine;
		return true;
	}

/**
* getTable : recupere le nom de la table utilisée
* @access public
* @return chaine 
*/
	function getConn()
	{
		return $this->conn;
	}

/**
* setTable : recupere le nom de la table utilisée
* @access public
* @param object objet classe "database"
* @return chaine 
*/
	function setConn(&$obj)
	{
		if (!is_object($obj))
			return false;

		$this->conn=&$obj;
		return true;
	}

/**
* doLoadFromGroupId: Charge la GroupUser depuis la BD
*
* <p>Retourne un tableau contenant les infos de l'objets
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </p>
* @access public
* @param entier identifiant de l'association GroupUser
* @return tableau
*/
	function doLoadFromId($id)
	{
		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("id")."=".$id;

		# Requete
		$tab=array();
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_numrows()!=0)
		{
			$tab=$this->conn->sql_fetchrow();
			$tab=$this->translateArray($tab);
		}else{
			$systemError=1;
			$classe="GroupUser";
			$message="Erreur dans GroupUserManagerDb";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}
		# Destruction des éléments
		$this->conn->sql_freeresult();					# Libération Mémoire
		return $tab;
	}

/**
* doLoadFromUserId: Charge la GroupUser depuis la BD
*
* <P>Retourne un tableau contenant les infos des utilisateur
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </P>
* @access public
* @param entier identifiant de l'association GroupUser
* @return tableau
*/
	function doLoadFromUserId($id)
	{
		if (!is_numeric($id))
		{
			$systemError=1;
			$classe="GroupUser";
			$message="Erreur dans GroupUserManagerDb";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}

		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("user_id")."=".$id;

		# Requete
		$tab=array();
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_numrows()!=0)
		{
			# charge toutes les ligne
			for ($i=0; $i<$this->conn->sql_numrows(); $i++)
			{
				$tab[$i]=$this->conn->sql_fetchrow();
				$tab[$i]=$this->translateArray($tab[$i]);
			}
		}

		# Destruction des éléments
		$this->conn->sql_freeresult();
		return $tab;
	}

/**
* doLoadFromGroupId: Charge le GroupUser depuis la BD
*
* <P>Retourne un tableau contenant les infos de l'objets
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </P>
* @access public
* @param entier identifiant de l'association GroupUser
* @return tableau
*/
	function doLoadFromGroupId($id)
	{
		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("group_id")."=".$id;

		# Requete
		$tab=array();
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_numrows()!=0)
		{
			for ($i=0; $i<$this->conn->sql_numrows(); $i++)
			{
				$tab[$i]=$this->conn->sql_fetchrow();
				$tab[$i]=$this->translateArray($tab[$i]);
			}
		}
		# Destruction des éléments
		$this->conn->sql_freeresult();
		return $tab;
	}

/**
* doInsert: Insert la GroupUser dans la BD
*
* <P>Insertion dans la Bd</P>
* @param entier identifiant de l'utilisateur
* @param entier identifiant du groupe
* @access public
* @return entier
*/
	function doInsert($userId, $groupId)
	{
		$sql="INSERT INTO ".$this->getTable()." ("
			.$this->getSqlName("user_id").", "
			.$this->getSqlName("group_id").") VALUES ("
			.$userId.", ".$groupId.")";

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_affectedrows()==0)
		{
			$systemError=1;
			$classe="GroupUser";
			$message="Erreur dans GroupUserManagerDb";
			addError($systemError,$classe,$message, __line__, __file__);
			return 0;
		}
		$retour=$this->conn->sql_nextid();
		return $retour;
	}

/**
* doUpdate:Modifie la GroupUser dans la BD
*
* <P>Mise à jour de la GroupUser</P>
* @param entier identifiant de l'association
* @param entier identifiant de l'utilisateur
* @param entier identifiant du groupe
* @access public
* @return booleen
*/
	function doUpdate($id, $userId, $groupId)
	{
		$sql="UPDATE ".$this->getTable()." SET ".$this->getSqlName("user_id")."=".$userId.", ".$this->getSqlName("group_id")."=".$groupId." WHERE ";
		$sql.=$this->getSqlName("id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);
		$retour=$id;
		return $retour;
	}

/**
* doDelete : Detruit le GroupUser dans la BD
*
* <P>Suppression de l'association Group et User à partir de son identifiant</P>
* @param entier identifiant
* @access public
* @return booleen
*/
	function doDelete($id)
	{
		$sql="DELETE FROM ".$this->getTable()." WHERE ".$this->getSqlName("id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_affectedrows()==0)
		{
			$systemError=1;
			$classe="GroupUser";
			$message="Erreur de SUPPRESSION dans GroupUserManagerDb";
			addError($systemError,$classe,$message, __line__, __file__);
			return false;
		}
		return true;
	}

	//////////////////////////////////////////////////////////////////////////
	//
	// Utilitaires pour la gestion des compatibilités BD
	//
	/////////////////////////////////////////////////////////////////////////
/**
* translateKey : change les cles du tableau resultant d'une requete en tableau de données pour l'objet
*
* <p>Supprime le nom de la table dans les noms de champs renvoy?s par la BD<br/>
* garde la compatibilité avec les version précédentes</p>
* @param array tableau sql
* @access private
* @return array tableau des attributs
*/
	function translateArray($sqlArray)
	{
		/* Cas nouvelle BD systeme */
		$result["id"]				=$sqlArray[$this->getSqlName('id')];
		$result["group_id"]			=$sqlArray[$this->getSqlName("group_id")];
		$result["user_id"]			=$sqlArray[$this->getSqlName("user_id")];
		return $result;
	}

/**
* initSqlAttributName : recupere le nom d'un attribut a partir d'une cle
*
* <p>En fonction de la version sql, on trouvera ici la correspondance entre le nom attribut de l'objet et son nom en BD<br/>
* cette methode permet de garder la compatibilité avec les version précédentes</p>
* @param chaine nom de l'attribut recherche
* @access private
* @return booleen
*/
	function initSqlAttribut()
	{
		if(defined('DATA_ACCES_TABLE_VERSION')){

			if( DATA_ACCES_TABLE_VERSION == 1){
				$this->sqlAttributArray["id"]		="group_user_id";
				$this->sqlAttributArray["group_id"]	="group_id";
				$this->sqlAttributArray["user_id"]	="user_id";

				return true;
			}
		}

		$this->sqlAttributArray["id"]				="id";
		$this->sqlAttributArray["group_id"]			="group_id";
		$this->sqlAttributArray["user_id"]			="user_id";
		return true;
	}

/**
* getSqlName : recupere le nom du champ a partir d'une cle
*
* <p>En fonction de la version sql, on trouvera ici la correspondance entre le nom attribut de l'objet et son nom en BD<br/>
* Cette methode permet de garder la compatibilite avec les version précédentes<br/>
* Elle s'appuie sur le tableau associatif $this->sqlAttributArray genere par initSqlAttributArray</p>
* @param chaine nom de l'attribut recherche
* @access private
* @return chaine nom du champ sql
*/
	function getSqlName($attribut)
	{
		return ( (isset($this->sqlAttributArray[$attribut]))?$this->sqlAttributArray[$attribut]:$attribut );
	}
}
?>
