<?php

/**------------------------------------------------
*
* Rooty, 2018 <rooty@rooty.me>
*
*
* This software is protected by copyright, please
* read the file COPYRIGHT.
* This program is distributed in the hope that it
* will be useful, but without any warranty; without
* even the implied warranty of merchantability or
* fitness for a particular purpose. Please
* read the file LICENCE.
*
*Fichier LanguageManager.php
*
*Ce fichier contient la classe LanguageManager
*
* @author Rooty <www.rooty.me|rooty@rooty.me>
* @link www.rooty.me
* @since 2004/06/05
* @version 0.3
* @package system_data
* @subpackage Language
* @copyright Copyright &copy; 2009-2018, Rooty
*/

#####################################################################################################
################################# Parametrage
#####################################################################################################
/**
* declaration du system... si cette variable n'est pas définie, les fichier inclus ne marche pas...
* cette variable est déclarée sur la page d'execution du script.
*<p> if ( !defined('SYSTEM_IN') )
* {
* die("Hacking attempt");
* }</p>
*/
if ( !defined('SYSTEM_IN') )
{
 die("Hacking attempt");
}

/**
* Appel à la classe Language...
*/
require ($CONF_LIB_PATH."lib/system/system_data/language/language.php");

/**
* Classe LanguageManager
*
* <P>Classe de gestion des instances de Languages <br>
*   (permet de fabriquer, detruire, mettre à jour des objet Languages)<br>
* Cette classe se sert des ressources à  sa disposition (dans ./ressource)<br>
* Les Classes de ressource doivent avoir toutes les methodes correspondantes <br>
* aux methodes de la classe intitulée sourceXXX</P>
* 
* <p>Est configuré dans data_acces.php : <br>
* - La Source d'information (Db)<br>
* l'objet ressource se sert lui-même des classes d'accès aux données(lib/data_source/...)<br>
* </p>
* @package system_data
* @subpackage Language
*/
class LanguageManager extends Manager
{

	//
	// Constructor
	//
/**
* Constructeur de la classe LanguageManager PHP5
*
* @access public
*/
	function __construct()
	{
	}



###########################################################################
#### MÃ©thodes abstraites
###########################################################################


/**
* doLoadFromId : charge la Langue depuis son id
*
* <P>Chargement depuis la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accès aux données</P>
* @param entier identifiant de la Langue
* @access public
* @abstract
* @return tableau tableau des éléments d'un Langue
*/
	function doLoadFromId($id)
	{
		return array();
	}

/**
* doLoadActive : charge les Langues actives
*
* <P>Chargement depuis la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accès aux données</P>
* @param entier identifiant de la Langue
* @access public
* @abstract
* @return tableau tableau sql des langues actives
*/
	function doLoadListActive()
	{
		return array();
	}

/**
* doLoad: charge toutes les langues
*
* <P>Chargement depuis la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accès aux données</P>
* @param entier identifiant de la Langue
* @access public
* @abstract
* @return tableau tableau de tableau des Ã©lÃ©ments de langue
*/
	function doLoadList()
	{
		return array();
	}

/**
* doUpdate : Update de la Langue
*
* <P>Chargement depuis la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accès aux données</P>
* @param chaine libelle de la Langue
* @param chaine code de la Langue
* @access public
* @abstract
* @return entier
*/
	function doUpdate($id, $libelle, $code, $status)
	{
		return 0;
	}

/**
* doInsert : Insert le Langue
*
* <P>Chargement depuis la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accès aux données</P>
* @param chaine libelle de la Langue
* @param chaine code de la Langue
* @access public
* @abstract
* @return entier
*/
	function doInsert($id, $libelle, $code, $status)
	{
		return true;
	}

/**
* doDelete : Detruit le Langue
*
* <P>Chargement depuis la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accès aux données</P>
* @param entier identifiant de la Langue
* @access public
* @abstract
* @return booleen
*/
	function doDelete($id)
	{
		return true;
	}


###########################################################################
#### MÃ©thodes privees
###########################################################################

/**
* sourceLoadListActive: charge les langues actives
*
* <p>Permet le récupération des infos des objet Language</p>
* <P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
* <p>Retourne un tableau contenant les infos de l'objet<br>
* <br>ou faux si n'existe pas</p>
* @param identifiant de la Langue
* @access private
* @return tableau
*/
	function sourceLoadListActive()
	{
		$tab=$this->doLoadListActive();
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if (!is_array($tab))
		{
			/* Erreur */
			$systemError=1;
			$classe="Language";
			$message="Erreur dans LanguageManager";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}else{
			return $tab;
		}
	}

/**
* sourceLoadList: charge les langues actives
*
* <p>Permet le récupération des infos des objet Language</p>
* <P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
*<p>Retourne un tableau contenant les infos de l'objet<br>
*<br>ou faux si n'existe pas</p>
* @param identifiant de la Langue
* @access private
* @return tableau
*/
	function sourceLoadList()
	{
		$tab=$this->doLoadList();
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if (!is_array($tab))
		{
			/* Erreur */
			$systemError=1;
			$classe="Language";
			$message="Erreur dans LanguageManager";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}else{
			return $tab;
		}
	}

/**
* sourceLoadFromId: charge à  partir d'un identifiant
*
* <p>Permet le récupération des infos des objet Language</p>
* <P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
* <p>Retourne un tableau contenant les infos de l'objet<br>
* <br>ou faux si n'existe pas</p>
* @param identifiant de la Langue
* @access private
* @return tableau
*/
	function sourceLoadFromId($id)
	{
		$tab=$this->doLoadFromId($id);
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if (!is_array($tab))
		{
			/* Erreur */
			$systemError=1;
			$classe="Language";
			$message="Erreur dans LanguageManager";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}else{
			if (!Is_numeric($tab["id"]))
			{
				/* Erreur */
				$systemError=1;
				$classe="Language";
				$message="Erreur dans LanguageManager";
				addError($systemError,$classe,$message, __line__, __file__);
				return array();
			}else{
				return $tab;
			}
		}
	}

/**
* sourceInsert: Insert le Langue
*
* <p>Insertion de l'objet Langue dans la source de données<br>
*  indifférement du type de cette source</p>
* <P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
* <p>Retourne L'identifiant de l'objet inséré</p>
* @param chaine libelle de la Langue
* @param chaine code de la Langue
* @access private
* @return entier
*/
	function sourceInsert($libelle, $code, $status)
	{
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if (!is_string($libelle) || !is_string($code))
		{
			/* Erreur */
			$systemError=1;
			$classe="Language";
			$message="Erreur dans LanguageManager";
			addError($systemError,$classe,$message, __line__, __file__);
			return false;
		}
		return $this->doInsert($libelle, $code, $status);
	}

/**
* sourceUpdate: Met à jour le Langue
* <P>Mise à  jour de l'objet indifferemment de la source de données</P>
* <P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
* @param entier identifiant de la Langue père
* @param chaine libelle de la Langue
* @param chaine code de la Langue
* @access private
* @return booleen
*/
	function sourceUpdate($id, $libelle, $code, $status)
	{
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if (!Is_numeric($id))
		{
			/* Erreur */
			$systemError=1;
			$classe="Language";
			$message="Erreur dans LanguageManager";
			addError($systemError,$classe,$message, __line__, __file__);
			return false;
		}
		return $this->doUpdate($id, $libelle, $code, $status);
	}

/**
* sourceDelete: Detruit le Langue
*
* <p>Suppression de l'objet à  partir de son identifiant</p>
* <P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
* @param entier identifiant de la Langue
* @access private
* @return booleen
*/
	function sourceDelete($id)
	{
		return $this->doDelete($id);
	}


###########################################################################
#### Méthodes public
###########################################################################


/**
* createNewInstance : créé un objet vierge
*
* @access public
* @return booleen
*/
	function createNewInstance()
	{
		return new Language();
	}

/**
* createInstance : récupere l'objet avec l'identifiant $id
*
* @param entier identifiant de l'association Language
* @access public
* @return object retourne un objet de type Language
*/
	function createInstance($id)
	{
		$return = new Language();
		if (is_numeric($id))
		{
			$tab=$this->sourceLoadFromId($id);
			if (is_array($tab) && isset($tab["id"]) && is_numeric($tab["id"]))
			{
				/* création et alimentation de l'objet */
				$return->doLoad($tab["id"], $tab["libelle"], $tab["code"], $tab["status"]);
			}else{
				$systemError=3;
				$classe="LanguageManager";
				$message="Erreur id inexistant ".$id;
				addError($systemError, $classe, $message, __line__, __file__);
			}
		}else{
			$systemError=3;
			$classe="LanguageManager";
			$message="Erreur id invalide ".$id;
			addError($systemError, $classe, $message, __line__, __file__);
		}
		return $return;
	}

/**
* createActiveLanguageList : retourne les langues actives
*
* @param entier identifiant de l'association Language
* @access public
* @return tableau tableau d'objets langue
*/
	function createActiveLanguageList()
	{
		$return = array();
		$tab=$this->sourceLoadListActive();
// 		var_dump($tab);
		if (is_array($tab))
		{
			for ($i=0; $i<count($tab); $i++)
			{
				$return[$i] = new Language();
				$return[$i]->doLoad($tab[$i]["id"], $tab[$i]["libelle"], $tab[$i]["code"], $tab[$i]["status"]);
// 				var_dump($return);
			}
		}else{
			$systemError=3;
			$classe="LanguageManager";
			$message="Erreur de format";
			addError($systemError, $classe, $message, __line__, __file__);
// 			var_dump("dohhhh!!!");
		}
		return $return;
	}

/**
* createActiveLanguageList : retourne les langues
*
* @param entier identifiant de l'association Language
* @access public
* @return tableau tableau d'objets langue
*/
	function createLanguageList()
	{
		$return = array();
		$tab=$this->sourceLoadList();
		if (is_array($tab))
		{
			for ($i=0; $i<count($tab); $i++)
			{
				$return[$i] = new Language();
				$return[$i]->doLoad($tab[$i]["id"], $tab[$i]["libelle"], $tab[$i]["code"], $tab[$i]["status"]);
			}
		}else{
			$systemError=3;
			$classe="LanguageManager";
			$message="Erreur de format";
			addError($systemError, $classe, $message, __line__, __file__);
		}
		return $return;
	}

/**
* deleteInstance : detruit l'objet physique
*
* @param object objet Language à effacer
* @access public
* @return object objetLanguage mis à jour
*/
	function deleteInstance($obj)
	{
		$return = false;
		if ((strtolower(get_class($obj))=="language"))
		{
			if($obj->isLoaded()==true)
			{
				$this->CallSystemPlugin("__deleteLanguage", $obj);
				$return=$this->sourceDeleteFromId($obj->getId());
				$obj->setId(0);
				return $obj;
			}
		}
		/* Erreur */
		$systemError=3;
		$classe="LanguageManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}

/**
* updateInstance : met à  jour l'objet
*
* @param object objet Language à modifier
* @access public
* @return object objetLanguage mis à jour
*/
	function updateInstance($obj)
	{
		$return = false;
		if ((strtolower(get_class($obj))=="language") && ($obj->isLoaded()==true))
		{
			$id=$this->sourceUpdate($obj->getId(), $obj->getXmlLibelle(), $obj->getCode(), $obj->getStatus());
			$this->CallSystemPlugin("__updateLanguage", $obj);
			return $obj;
		}
		/* Erreur */
		$systemError=3;
		$classe="LanguageManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}

/**
* insertInstance : enregistre l'objet
* <p>affecte l'id de l'objet si nécessaire</p>
* @param object objet Language à inserer
* @access public
* @return object objetLanguage mis a jour
*/
	function insertInstance($obj)
	{
		if ((strtolower(get_class($obj))=="language"))
		{
			if ($obj->isLoaded()==false)
			{
				/* RÃ©cupÃ©ration des infos */
				$id=$this->sourceInsert($obj->getXmlLibelle(), $obj->getCode(), $obj->getStatus());
				$obj->setId($id);
				$this->CallSystemPlugin("__insertLanguage", $obj);
				return $obj;
			}
		}
		/* Erreur */
		$systemError=3;
		$classe="LanguageManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}

/**
* saveInstance : enregistre l'objet
* @param object objet Language à sauvegarder
* @access public
* @return object objetLanguage mis à jour
*/
	function saveInstance($obj)
	{
		if ((strtolower(get_class($obj))=="language"))
		{
			if ($obj->isLoaded()==false)
			{
				$return=$this->insertInstance($obj);
			}else{
				$return=$this->updateInstance($obj);
			}
			return $return;
		}
		/* Erreur */
		$systemError=3;
		$classe="LanguageManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);
		$return=$obj;

		return $return;
	}
}
?>
