<?php

/**------------------------------------------------
*
* Rooty, 2018 <rooty@rooty.me>
*
*
* This software is protected by copyright, please
* read the file COPYRIGHT.
* This program is distributed in the hope that it
* will be useful, but without any warranty; without
* even the implied warranty of merchantability or
* fitness for a particular purpose. Please
* read the file LICENCE.
*
* Fichier LanguageManagerDb.php
*
* Ce fichier contient la classe LanguageManagerDb
*
* @author Rooty <www.rooty.me|rooty@rooty.me>
* @link www.rooty.me
* @since 2004/04/14
* @version 0.3
* @package system_data
* @subpackage Language
* @copyright Copyright &copy; 2009-2018, Rooty
*/

#####################################################################################################
################################# Parametrage
#####################################################################################################
/**
* declaration du system... si cette variable n'est pas définie, les fichier inclus ne marche pas...
* cette variable est déclarée sur la page d'execution du script.
* <p> if ( !defined('SYSTEM_IN') )
* {
* die("Hacking attempt");
* }</p>
*/
if ( !defined('SYSTEM_IN') )
{
 die("Hacking attempt");
}

/**
* Classe LanguageManagerDb
*
* classe de gestion des Languages pour une do de données database (type gérés par database)<br><br>
* Sont configuré dans config_data_acces.php:<br>
* - La do d'information <br>
*    (actuellement seul DB possible->Pour ajouter une do reproduire LanguageLanguageManagerDb)<br>
* - Le Nom de la Table<br>
* - La configuration (Paramétrage des dos de do de données) est faite dans config_data_do.php<br>
* - La declaration de la connexion est faite à partir de config_system.php
*
* @package system_data
* @subpackage Language
*/
class LanguageManagerDb extends LanguageManager
{

/**
* @var chaine
* @access private
* @desc ID de la Language
*/
var $table		= "";

/**
* @var object
* @access private
* @desc objet database
*/
var $conn		= null;

	//
	// Constructor
	//

/**
* Constructeur de la classe LanguageManagerDb PHP4
* <p>Initialise la LanguageManagerDb</p>
*
* @access public
*/
	function LanguageManagerDb()
	{
		$this->__construct();
	}

/**
* Constructeur de la classe LanguageManagerDb PHP5
* <p>Initialise la LanguageManagerDb</p>
*
* @access public
*/
	function __construct()
	{
		$this->setTable( DATA_ACCES_TABLE_LANGUAGE );	/* Appel à la constant correspondant */
		$this->initSqlAttribut();			/* initialisation des noms de champs */
		$this->setConn($GLOBALS['SYSTEM_DATABASE_CONN']);
	}

/**
* getTable : recupere le nom de la table utilisée
* @access public
* @return chaine
*/
	function getTable()
	{
		return $this->table;
	}

/**
* setTable : recupere le nom de la table utilisée
* @access public
* @param chaine nom de la table
* @return chaine
*/
	function setTable($chaine)
	{
		if (!is_string($chaine))
			return false;

		$this->table=$chaine;
		return true;
	}

/**
* getTable : recupere le nom de la table utilisée
* @access public
* @return chaine
*/
	function getConn()
	{
		return $this->conn;
	}

/**
* setTable : recupere le nom de la table utilisée
* @access public
* @param object objet classe "database"
* @return chaine
*/
	function setConn(&$obj)
	{
		if (!is_object($obj))
			return false;

		$this->conn=&$obj;
		return true;
	}

/**
* doLoadFromId: Charge le Langue depuis la BD
*
* <p>Retourne un tableau contenant les infos de l'objet</p>
* @access private
* @param entier identifiant de la Langue
* @return tableau
*/
	function doLoadFromId($id)
	{
		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_numrows()==0)
		{
			/* Erreur */
			$systemError=1;
			$classe="LanguageManager";
			$message="Erreur objet invalide ";
			addError($systemError, $classe, $message, __line__, __file__);
			return array();
		}

		$tab=$this->conn->sql_fetchrow();
		$tab = $this->translateArray($tab);

		# Destruction des éléments
		$this->conn->sql_freeresult();
		return $tab;
	}

/**
* doLoadListActive: Charge les Langue depuis la BD
*
* <p>Retourne un tableau contenant les infos de l'objet</p>
* @access private
* @param entier identifiant de la Langue
* @return tableau
*/
	function doLoadListActive()
	{
		$rs=array();
		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("status")."=1";

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_numrows()==0)
		{
			/* Erreur */
			$systemError=1;
			$classe="LanguageManager";
			$message="Erreur objet invalide ";
			addError($systemError, $classe, $message, __line__, __file__);
			return array();
		}

		for ($i=0;$i<$this->conn->sql_numrows(); $i++)
		{
			$tab[$i]=$this->conn->sql_fetchrow();
			$tab[$i]=$this->translateArray($tab[$i]);
		}

		# Destruction des éléments
		$this->conn->sql_freeresult();
		return $tab;
	}

/**
* doLoadList: Charge les Langue depuis la BD
*
* <p>Retourne un tableau contenant les infos de l'objet</p>
* @access private
* @param entier identifiant de la Langue
* @return tableau
*/
	function doLoadList()
	{
		$rs=array();
		$sql="SELECT * FROM ".$this->getTable()."";

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_numrows()==0)
		{
			/* Erreur */
			$systemError=1;
			$classe="LanguageManager";
			$message="Erreur objet invalide ";
			addError($systemError, $classe, $message, __line__, __file__);
			return array();
		}

		for ($i=0;$i<$this->conn->sql_numrows(); $i++)
		{
			$tab[$i]=$this->conn->sql_fetchrow();
			$tab[$i]=$this->translateArray($tab[$i]);
		}

		# Destruction des éléments
		$this->conn->sql_freeresult();
		return $tab;
	}

/**
* doInsert: Insert le Langue dans la BD
*
* <P>Insertion dans la Bd</P>
* @param chaine libelle de la Langue
* @param chaine code de la Langue
* @access private
* @return entier
*/
	function doInsert($id, $libelle, $code, $status)
	{
		$sql="INSERT INTO ".$this->getTable()." (".$this->getSqlName("libelle").", ".$this->getSqlName("code").",  ".$this->getSqlName("status").") VALUES (";
		$sql.="'".$libelle."', '".$code."', ".$status.")";

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_affectedrows()==0)
		{
			/* Erreur */
			$systemError=1;
			$classe="LanguageManager";
			$message="Erreur objet invalide ";
			addError($systemError, $classe, $message, __line__, __file__);
			return 0;
		}
		$retour=$this->conn->sql_nextid();
		return $retour;
	}

/**
* doUpdate : Modifie le Langue dans la BD
*
* <P>Mise à jour de la Language</P>
* @param entier identifiant
* @param chaine libelle de la Langue
* @param chaine code de la Langue
* @access private
* @return booleen
*/
	function doUpdate($id, $libelle, $code, $status)
	{
		$sql="UPDATE ".$this->getTable()." SET ".$this->getSqlName("libelle")."='".$libelle."', ".$this->getSqlName("code")."='".$code."', ".$this->getSqlName("status")."=".$status." WHERE ";
		$sql.=$this->getSqlName("id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);
		$retour=$id;
		return $retour;
	}

/**
* doDelete : Detruit le Langue dans la BD
*
* <p>Suppression de la Langue à partir de son identifiant</p>
* @param entier identifiant de la Langue
* @access private
* @return booleen
*/
	function doDelete($id)
	{
		$sql="DELETE FROM ".$this->getTable()." WHERE ".$this->getSqlName("id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_affectedrows()==0)
		{
			/* Erreur */
			$systemError=1;
			$classe="LanguageManager";
			$message="Erreur objet invalide ";
			addError($systemError, $classe, $message, __line__, __file__);
			return false;
		}
		return true;
	}

	//////////////////////////////////////////////////////////////////////////
	//
	// Utilitaires pour la gestion des compatibilités BD
	//
	/////////////////////////////////////////////////////////////////////////
/**
* translateKey : change les cles du tableau resultant d'une requete en tableau de données pour l'objet
*
* <p>Supprime le nom de la table dans les noms de champs renvoy?s par la BD<br/>
* garde la compatibilité avec les version précédentes</p>
* @param array tableau sql
* @access private
* @return array tableau des attributs
*/
	function translateArray($sqlArray)
	{
		/* Cas nouvelle BD systeme */
		$result["id"]				=$sqlArray[$this->getSqlName('id')];
		$result["libelle"]			=$sqlArray[$this->getSqlName("libelle")];
		$result["code"]				=$sqlArray[$this->getSqlName("code")];
		$result["status"]			=$sqlArray[$this->getSqlName("status")];
		return $result;
	}

/**
* initSqlAttributName : recupere le nom d'un attribut a partir d'une cle
*
* <p>En fonction de la version sql, on trouvera ici la correspondance entre le nom attribut de l'objet et son nom en BD<br/>
* cette methode permet de garder la compatibilité avec les version précédentes</p>
* @param chaine nom de l'attribut recherche
* @access private
* @return booleen
*/
	function initSqlAttribut()
	{
		if(defined('DATA_ACCES_TABLE_VERSION'))
		{
			if( DATA_ACCES_TABLE_VERSION == 1)
			{
				$this->sqlAttributArray["id"]				="langue_id";
				$this->sqlAttributArray["libelle"]			="langue_libelle";
				$this->sqlAttributArray["code"]				="langue_code";
				$this->sqlAttributArray["status"]			="langue_status";
				return true;
			}
		}
		$this->sqlAttributArray["id"]				="id";
		$this->sqlAttributArray["libelle"]			="libelle";
		$this->sqlAttributArray["code"]				="code";
		$this->sqlAttributArray["status"]			="status";
		return true;
	}

/**
* getSqlName : recupere le nom du champ a partir d'une cle
*
* <p>En fonction de la version sql, on trouvera ici la correspondance entre le nom attribut de l'objet et son nom en BD<br/>
* Cette methode permet de garder la compatibilite avec les version précédentes<br/>
* Elle s'appuie sur le tableau associatif $this->sqlAttributArray genere par initSqlAttributArray</p>
* @param chaine nom de l'attribut recherche
* @access private
* @return chaine nom du champ sql
*/
	function getSqlName($attribut)
	{
		return ( (isset($this->sqlAttributArray[$attribut]))?$this->sqlAttributArray[$attribut]:$attribut );
	}
}
?>
