<?php
/**------------------------------------------------
*
* Rooty, 2018 <rooty@rooty.me>
*
*
* This software is protected by copyright, please
* read the file COPYRIGHT.
* This program is distributed in the hope that it
* will be useful, but without any warranty; without
* even the implied warranty of merchantability or
* fitness for a particular purpose. Please
* read the file LICENCE.
*
* Fichier NodeGroupUserManager.php
*
* Ce fichier contient la classe NodeGroupUserManager
*
* @author Rooty <www.rooty.me|rooty@rooty.me>
* @link www.rooty.me
* @since 2004/06/05
* @version 0.3
* @package system_data
* @subpackage NodeGroupUser
* @copyright Copyright &copy; 2009-2018, Rooty
*/

#####################################################################################################
################################# Parametrage
#####################################################################################################

/**
* declaration du system... si cette variable n'est pas définie, les fichier inclus ne marche pas...
* cette variable est déclarée sur la page d'execution du script.
* <p> if ( !defined('SYSTEM_IN') )
* {
* die("Hacking attempt");
* }</p>
*/
if ( !defined('SYSTEM_IN') )
{
 die("Hacking attempt");
}

/**
* Appel à la classe NodeGroupUser...
*/
require ($CONF_LIB_PATH."lib/system/system_data/nodegroupuser/nodegroupuser.php");

/**
* Classe NodeGroupUserManager
*
* <p>Classe de gestion des instances de NodeGroupUsers <br>
*   (permet de fabriquer, detruire, mettre à jour des objet NodeGroupUsers)<br>
* Cette classe se sert des ressources à sa disposition (dans ./ressource)<br>
* Les Classes de ressource doivent avoir toutes les methodes correspondantes <br>
* aux methodes de la classe intitulés sourceXXX</p>
*
* <p>Est configuré dans data_acces.php : <br>
* - La Source d'information (Db)<br>
* l'objet ressource se sert lui-même des classes d'accés aux données(lib/data_source/...)<br>
* </p>
* @package system_data
* @subpackage NodeGroupUser
*/

class NodeGroupUserManager extends Manager
{

	//
	// Constructor
	//
/**
* Constructeur de la classe NodeGroupUserManager PHP5
*
* @access public
*/
	function __construct()
	{
	}


###########################################################################
#### Méthodes abstraites
###########################################################################

/**
* doLoadFromGroupId: Charge la NodeGroupUser depuis la BD
*
* <p>Retourne un tableau contenant les infos de l'objets
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </p>
* @access public
* @abstract
* @param entier identifiant de l'association NodeGroupUser
* @return tableau
*/
	function doLoadFromId($id)
	{
		return array();
	}

/**
* doLoadFromUserId: Charge la NodeGroupUser depuis la BD
*
* <P>Retourne un tableau contenant les infos des utilisateur
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </P>
* @access public
* @param entier identifiant de l'association NodeGroupUser
* @param tableau identifiant des groupes de l'utilisateur
* @abstract
* @return tableau
*/
	function doLoadFromUserId($id, $array)
	{
		return array();
	}

/**
* doLoadFromGroupId: Charge le NodeGroupUser depuis la BD
*
* <P>Retourne un tableau contenant les infos de l'objets
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </P>
* @access public
* @param entier identifiant de l'association NodeGroupUser
* @abstract
* @return tableau
*/
	function doLoadFromGroupId($id)
	{
		return array();
	}

/**
* doLoadFromNodeId: Charge le NodeGroupUser depuis la BD
*
* <P>Retourne un tableau contenant les infos de l'objets
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </P>
* @access public
* @param entier identifiant de l'association NodeGroupUser
* @abstract
* @return tableau
*/
	function doLoadFromNodeId($id)
	{
		return array();
	}

/**
* doInsert: Insert la NodeGroupUser dans la BD
*
* <P>Insertion dans la Bd</P>
* @param entier identifiant de l'utilisateur
* @param entier identifiant du groupe
* @param entier booleen
* @abstract
* @access public
* @return entier
*/
	function doInsert($userId, $groupId, $nodeId)
	{
		return 0;
	}

/**
* doUpdate:Modifie la NodeGroupUser dans la BD
*
* <P>Mise à jour de la NodeGroupUser</P>
* @param entier identifiant de l'association
* @param entier identifiant de l'utilisateur
* @param entier identifiant du groupe
* @param booleen is node only
* @param booleen is forbidden
* @access public 
* @abstract
* @return booleen
*/
	function doUpdate($id, $userId, $groupId, $nodeId)
	{
		return 0;
	}

/**
* doDelete : Detruit le NodeGroupUser dans la BD
*
* <P>Suppression de l'association Group et User à partir de son identifiant</P>
* @param entier identifiant
* @abstract
* @access public
* @return booleen
*/
	function doDelete($id)
	{
		return true;
	}


###########################################################################
#### Methodes privee
###########################################################################

/**
* sourceLoadFromUserId : charge à partir d'un identifiant utilisateur
*
* <p>Permet le récupération des infos d'un objet NodeGroupUser à partir de son identifiant</p>
* <p>Retourne un tableau contenant les infos de l'objets<br>
* <br>ou faux si n'existe pas
* </p>
* @param identifiant de l'association NodeGroupUser
* @access private
* @return tableau
*/
	function sourceLoadFromId($id)
	{
		$tab=$this->doLoadFromId($id);
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if ((!is_array($tab)) || (count($tab)==0) || (!Is_numeric($tab["id"])))
		{
			$systemError=2;
			$classe="NodeGroupUser";
			$message="Erreur de SUPPRESSION dans FetchNodeGroupUserDb avec l'id ".$id;
			addError($systemError, $classe, $message, __line__, __file__);
			return array();
		}

		return $tab;
	}

/**
* sourceLoadFromUserId : charge à partir d'un identifiant utilisateur
*
* <p>Permet le récupération des infos d'un objet NodeGroupUser à partir de son identifiant</p>
* <p>Retourne un tableau contenant les infos de l'objets<br>
* <br>ou faux si n'existe pas
* </p>
* @param identifiant de l'association NodeGroupUser
* @access private
* @return tableau
*/
	function sourceLoadFromUserId($id, $array)
	{
		$tab=$this->doLoadFromUserId($id, $array);
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if ((!is_array($tab)) && (!Is_numeric($tab["id"])))
		{
			$systemError=2;
			$classe="NodeGroupUser";
			$message="Erreur de Load dans FetchNodeGroupUserDb";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}

		return $tab;
	}

/**
* sourceLoadFromGroupId : charge à partir d'un identifiant de groupe
*
* <p>Permet le récupération des infos d'un objet NodeGroupUser à partir de son identifiant</p>
* <p>Retourne un tableau contenant les infos de l'objets<br>
* <br>ou faux si n'existe pas
* </p>
* @param identifiant de l'association NodeGroupUser
* @access private
* @return tableau
*/
	function sourceLoadFromGroupId($id)
	{
		$tab=$this->doLoadFromGroupId($id);
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if ((!is_array($tab)) && (!Is_numeric($tab["id"])))
		{
			$systemError=2;
			$classe="NodeGroupUser";
			$message="Erreur de Load dans FetchNodeGroupUserDb";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}

		return $tab;
	}

/**
* sourceLoadFromNodeId : charge à partir d'un identifiant de groupe
*
* <p>Permet le récupération des infos d'un objet NodeGroupUser à partir de son identifiant</p>
* <p>Retourne un tableau contenant les infos de l'objets<br>
* <br>ou faux si n'existe pas
* </p>
* @param identifiant de l'association NodeGroupUser
* @access private
* @return tableau
*/
	function sourceLoadFromNodeId($id)
	{
		$tab=$this->doLoadFromNodeId($id);
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if ((!is_array($tab)) && (!Is_numeric($tab["id"])))
		{
			$systemError=2;
			$classe="NodeGroupUser";
			$message="Erreur de Load dans FetchNodeGroupUserDb";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}

		return $tab;
	}


/**
* sourceInsertFromParam : Insert la NodeGroupUser
*
* <p>Insertion de l'objet NodeGroupUser dans la source de données<br>
* indifférement du type de cette source</p>
* <p>Retourne L'identifiant de l'objet insérer</p>
* @param chaine libelle de la NodeGroupUser
* @param chaine repertoire de la NodeGroupUser
* @param chaine icone de la NodeGroupUser
* @param entier état de la NodeGroupUser (active ou inactive)
* @access private
* @return entier
*/
	function sourceInsert($userId, $groupId, $nodeId)
	{
		# Gestion d'un tableau intermediaire avec la reprise des elements
		return $this->doInsert($userId, $groupId, $nodeId);
	}

/**
* sourceUpdateFromParam : Met à jour la NodeGroupUser
*
* <p>Mise à jour de l'objet indifferemment de la source de données</p>
* @param entier identifiant
* @param chaine libelle de la NodeGroupUser
* @param chaine repertoire de la NodeGroupUser
* @param chaine icone de la NodeGroupUser
* @param entier état de la NodeGroupUser (active ou inactive)
* @access private
* @return booleen
*/
	function sourceUpdate($id, $userId, $groupId, $nodeId)
	{
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if (!Is_numeric($id))
		{
			$systemError=1;
			$classe="NodeGroupUser";
			$message="Erreur de Modification dans NodeGroupUserManager avec l'id ".$id;
			addError($systemError, $classe, $message, __line__, __file__);
			return false;
		}
		return $this->doUpdate($id, $userId, $groupId, $nodeId);
	}

/**
* sourceDeleteFromId : Detruit la NodeGroupUser
*
* <p>Suppression de l'objet à partir de son identifiant</p>
* @param entier identifiant de l'association NodeGroupUser
* @access private
* @return booleen
*/
	function sourceDeleteFromId($id)
	{
		if (!Is_numeric($id))
		{
			$systemError=2;
			$classe="NodeGroupUser";
			$message="Erreur de SUPRESSION dans NodeGroupUserManager avec l'id ".$id;
			addError($systemError,$classe,$message, __line__, __file__);

			return false;
		}
		return $this->doDelete($id);
	}


###########################################################################
#### Methodes public
###########################################################################

/**
* createNewInstance : créer un objet vierge
*
* @access public
* @return objet
*/
	function createNewInstance()
	{
		return new NodeGroupUser();
	}
/**
* createInstance : récupere l'objet avec l'identifiant $id
*
* @param entier identifiant de l'association NodeGroupUser
* @access public
* @return object retourne un objet de type NodeGroupUser
*/
	function createInstance($id)
	{
		$return = new NodeGroupUser();
		if (is_numeric($id))
		{
			/* Récupération des infos */
			$tab=$this->sourceLoadFromId($id);
			if (is_array($tab) && isset($tab["id"]) && is_numeric($tab["id"]))
			{
				/* création et alimentation de l'objet */
				$return->doLoad($tab["id"], $tab["user_id"], $tab["group_id"], $tab["node_id"]);
			}else{
				$systemError=3;
				$classe="NodeGroupUserManager";
				$message="Erreur id inexistant ".$id;
				addError($systemError, $classe, $message, __line__, __file__);
			}
		}else{
			$systemError=3;
			$classe="NodeGroupUserManager";
			$message="Erreur id invalide ".$id;
			addError($systemError, $classe, $message, __line__, __file__);
		}
		return $return;
	}
/**
* deleteInstance : detruit l'objet physique
*
* @param object objet NodeGroupUser à effacer
* @access public
* @return object objetNodeGroupUser mis à jour
*/
	function deleteInstance($obj)
	{
		$return = false;
		if ((strtolower(get_class($obj))=="nodegroupuser") )
		{
			if($obj->isLoaded()==true)
			{
				/* Récupération des infos */
				$this->CallSystemPlugin("__deleteNodeGroupUser", $obj);
				$return=$this->sourceDeleteFromId($obj->getId());
				$obj->setId(0);
				return $obj;
			}
		}
		/* Erreur */
		$systemError=3;
		$classe="NodeGroupUserManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}

/**
* updateInstance : met à jour l'objet
*
* @param object objet NodeGroupUser à modifier
* @access public
* @return object objetNodeGroupUser mis à jour
*/
	function updateInstance($obj)
	{
		$return = false;
		if ((strtolower(get_class($obj))=="nodegroupuser") && ($obj->isLoaded()==true))
		{
			/* Récupération des infos */
			$id=$this->sourceUpdate($obj->getId(), $obj->getUserId(), $obj->getGroupId(), $obj->getNodeId() );
			$this->CallSystemPlugin("__updateNodeGroupUser", $obj);
			return $obj;
		}
		/* Erreur */
		$systemError=3;
		$classe="NodeGroupUserManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}
/**
* insertInstance : créer enregistre l'objet
*
* <p>affecte l'id de l'objet si nécessaire</p>
* @param object objet NodeGroupUser à inserer
* @access public
* @return object objetNodeGroupUser mis à jour
*/
	function insertInstance($obj)
	{
		if ((strtolower(get_class($obj))=="nodegroupuser"))
		{
			if ($obj->isLoaded()==false)
			{
				/* Récupération des infos */
				$id=$this->sourceInsert($obj->getUserId(), $obj->getGroupId(), $obj->getNodeId());
				$obj->setId($id);
				$this->CallSystemPlugin("__insertNodeGroupUser", $obj);
				return $obj;
			}
		}
		/* Erreur */
		$systemError=3;
		$classe="NodeGroupUserManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}
/**
* saveInstance : créer enregistre l'objet
*
* @param object objet NodeGroupUser à sauvegarder
* @access public
* @return object objetNodeGroupUser mis à jour
*/
	function saveInstance($obj)
	{
		if ((strtolower(get_class($obj))=="nodegroupuser"))
		{
			if ($obj->isLoaded()==false)
			{
				$return=$this->insertInstance($obj);
			}else{
				$return=$this->updateInstance($obj);
			}
			return $return;
		}
		/* Erreur */
		$systemError=3;
		$classe="NodeGroupUserManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);
		$return=$obj;

		return $return;
	}

/**
* getInstanceFromUserId : récupere les objets NodeGroupUser de l'utilisateur($id) ayant pour groupe (tableau de groupe $groupe)
*
* @param entier identifiant de l'utilisateur
* @param tableau tableau des groupes associés à l'utilisateur
* @access public
* @return tableau tableau d'objets NodeGroupUser
*/
	function getInstanceFromUserId($id, $groupe)
	{
		$return = array();		/* Tableau de NodeUserGroup */
		if (is_numeric($id))
		{
			/* Récupération des infos */
			$tab=$this->sourceLoadFromUserId($id, $groupe);
			if (is_array($tab))
			{
				/* création et alimentation de l'objet */
				for ($i=0; $i<count($tab); $i++)
				{
					$return[$i]=new NodeGroupUser();
					$return[$i]->doLoad($tab[$i]["id"], $tab[$i]["user_id"], $tab[$i]["group_id"], $tab[$i]["node_id"]);
				}
			}else{
				$systemError=3;
				$classe="NodeGroupUserManager";
				$message="Erreur objet invalide ";
				addError($systemError, $classe, $message, __line__, __file__);
			}
		}else{
			$systemError=3;
			$classe="NodeGroupUserManager";
			$message="Erreur objet invalide ";
			addError($systemError, $classe, $message, __line__, __file__);
		}
		return $return;
	}

/**
* getInstanceFromGroupId : récupere les objets NodeGroupUser pour le groupe
*
* @param entier identifiant du groupe
* @access public
* @return tableau tableau d'objets NodeGroupUser
*/
	function getInstanceFromGroupId($id)
	{
		$return = array();		/* Tableau de NodeUserGroup */
		if (is_numeric($id))
		{
			/* Récupération des infos */
			$tab=$this->sourceLoadFromGroupId($id);
			if (is_array($tab))
			{
				/* création et alimentation du tableau */
				for ($i=0; $i<count($tab); $i++)
				{
					$return[$i]=new NodeGroupUser();
					$return[$i]->doLoad($tab[$i]["id"], $tab[$i]["user_id"], $tab[$i]["group_id"], $tab[$i]["node_id"]);
				}
			}else{
				$systemError=3;
				$classe="NodeGroupUserManager";
				$message="Erreur objet invalide ";
				addError($systemError, $classe, $message, __line__, __file__);
			}
		}else{
			$systemError=3;
			$classe="NodeGroupUserManager";
			$message="Erreur objet invalide ";
			addError($systemError, $classe, $message, __line__, __file__);
		}
		return $return;
	}
/**
* getInstanceFromNodeId : récupere les objets NodeGroupUser pour le Noeud
*
* @param entier identifiant du groupe
* @access public
* @return tableau tableau d'objets NodeGroupUser
*/
	function getInstanceFromNodeId($id)
	{
		$return = array();		/* Tableau de NodeUserGroup */
		if (is_numeric($id))
		{
			/* Récupération des infos */
			$tab=$this->sourceLoadFromNodeId($id);
			if (is_array($tab))
			{
				/* création et alimentation du tableau */
				for ($i=0; $i<count($tab); $i++)
				{
					$return[$i]=new NodeGroupUser();
					$return[$i]->doLoad($tab[$i]["id"], $tab[$i]["user_id"], $tab[$i]["group_id"], $tab[$i]["node_id"]);
				}
			}else{
				$systemError=3;
				$classe="NodeGroupUserManager";
				$message="Erreur objet invalide ";
				addError($systemError, $classe, $message, __line__, __file__);
			}
		}else{
			$systemError=3;
			$classe="NodeGroupUserManager";
			$message="Erreur objet invalide ";
			addError($systemError, $classe, $message, __line__, __file__);
		}
		return $return;
	}
}
?>
