<?php

/**------------------------------------------------
*
* Rooty, 2018 <rooty@rooty.me>
*
*
* This software is protected by copyright, please
* read the file COPYRIGHT.
* This program is distributed in the hope that it
* will be useful, but without any warranty; without
* even the implied warranty of merchantability or
* fitness for a particular purpose. Please
* read the file LICENCE.
*
* Fichier NodeGroupUserManagerDb.php
*
* Ce fichier contient la classe NodeGroupUserManagerDb
*
* @author Rooty <www.rooty.me|rooty@rooty.me>
* @link www.rooty.me
* @since 2004/04/14
* @version 0.3
* @package system_data
* @subpackage NodeGroupUser
* @copyright Copyright &copy; 2009-2018, Rooty
*/

#####################################################################################################
################################# Parametrage
#####################################################################################################
/**
* declaration du system... si cette variable n'est pas définie, les fichier inclus ne marche pas...
* cette variable est déclarée sur la page d'execution du script.
* <p> if ( !defined('SYSTEM_IN') )
* {
* die("Hacking attempt");
* }</p>
*/
if ( !defined('SYSTEM_IN') )
{
 die("Hacking attempt");
}

/**
* Classe NodeGroupUserManagerDb
*
* classe de gestion des NodeGroupUsers pour une do de données database (type gérés par database)<br><br>
* Sont configuré dans config_data_acces.php:<br>
* - La do d'information <br>
*    (actuellement seul DB possible->Pour ajouter une do reproduire NodeGroupUserManagerDb)<br>
* - Le Nom de la Table<br>
* - La configuration (Paramétrage des dos de do de données) est faite dans config_data_do.php<br>
* - La declaration de la connexion est faite à partir de config_system.php
*
* @package system_data
* @subpackage NodeGroupUser
*/
class NodeGroupUserManagerDb extends NodeGroupUserManager
{

/**
* @var chaine
* @access private
* @desc ID de la NodeGroupUser
*/
var $table		= "";

/**
* @var object
* @access private
* @desc objet database
*/
var $conn		= null;

	//
	// Constructor
	//

/**
* Constructeur de la classe NodeGroupUserManagerDb PHP4
*
* <p>Initialise la NodeGroupUserManagerDb</p>
* @access public
*/
	function NodeGroupUserManagerDb()
	{
		$this->__construct();
	}

/**
* Constructeur de la classe NodeGroupUserManagerDb PHP5
*
* <p>Initialise la NodeGroupUserManagerDb</p>
* @access public
*/
	function __construct()
	{
		$this->setTable( DATA_ACCES_TABLE_NODE_GROUP_USER );	/* Appel à la constant correspondant */
		$this->initSqlAttribut();				/* initialisation des noms de champs */
		$this->setConn($GLOBALS['SYSTEM_DATABASE_CONN']);
	}

/**
* getTable : recupere le nom de la table utilisée
* @access public
* @return chaine
*/
	function getTable()
	{
		return $this->table;
	}

/**
* setTable : recupere le nom de la table utilisée
* @access public
* @param chaine nom de la table
* @return chaine
*/
	function setTable($chaine)
	{
		if (!is_string($chaine))
			return false;

		$this->table=$chaine;
		return true;
	}

/**
* getTable : recupere le nom de la table utilisée
* @access public
* @return chaine
*/
	function getConn()
	{
		return $this->conn;
	}

/**
* setTable : recupere le nom de la table utilisée
* @access public
* @param object objet classe "database"
* @return chaine
*/
	function setConn(&$obj)
	{
		if (!is_object($obj))
			return false;

		$this->conn=&$obj;
		return true;
	}

/**
* doLoadFromId: Charge la NodeGroupUser depuis la BD
* <p>Retourne un tableau contenant les infos de l'objets</p>
* @access public
* @param entier identifiant de l'association NodeGroupUser
* @return tableau
*/
	function doLoadFromId($id)
	{
		$tab=array();		/* initialisation du retour */
		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("id")."=".$id;

		/* Requete */
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_numrows()==0)
		{
			$systemError=1;
			$classe="NodeGroupUser";
			$message="Erreur dans NodeGroupUserManagerDb ";
			addError($systemError, $classe, $message, __line__, __file__);
			return $tab;
		}

		/* charge la ligne */
		$tab=$this->conn->sql_fetchrow();
		$tab=$this->translateArray($tab);
		$this->conn->sql_freeresult();
		return $tab;
	}

/**
* doLoadFromUserId: Charge la NodeGroupUser depuis la BD
*<p>Retourne un tableau contenant les infos des utilisateur</p>
* @access public
* @param entier identifiant de l'association NodeGroupUser
* @return tableau
*/
	function doLoadFromUserId($id, $array)
	{
		$tab=array();		/* initialisation du retour */

		if ((!is_numeric($id)) || (!is_array($array)))
		{
			$systemError=1;
			$classe="NodeGroupUser";
			$message="Erreur dans NodeGroupUserManagerDb ";
			addError($systemError, $classe, $message, __line__, __file__);
			return array();
		}

		$nbGroup=count($array);
		$optGroup="";

		# Génération des option pour les informations...
		for ($i=0; $i<$nbGroup; $i++)
		{
			$optGroup.=" OR (".$this->getSqlName("group_id")."=".$array[$i].")";
		}
		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("user_id")."=".$id.$optGroup;

		/* Requete */
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_numrows()!=0)
		{
			/* charge toutes les ligne */
			for ($i=0; $i<$this->conn->sql_numrows(); $i++)
			{
				$tab[$i]=$this->conn->sql_fetchrow();
				$tab[$i]=$this->translateArray($tab[$i]);
			}
		}
		$this->conn->sql_freeresult();
		return $tab;
	}

/**
* doLoadFromGroupId: Charge la NodeGroupUser depuis la BD
*<p>Retourne un tableau contenant les infos pour le groupe</p>
* @access public
* @param entier identifiant de l'association NodeGroupUser
* @return tableau
*/
	function doLoadFromGroupId($id)
	{
		$tab=array();		# initialisation du retour
		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("group_id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_numrows()!=0)
		{
			# charge toutes les ligne
			for ($i=0; $i<$this->conn->sql_numrows(); $i++)
			{
				$tab[$i]=$this->conn->sql_fetchrow();
				$tab[$i]=$this->translateArray($tab[$i]);
			}
		}
		$this->conn->sql_freeresult();
		return $tab;
	}

/**
* doLoadFromNodeId: Charge la NodeGroupUser depuis la BD
*<p>Retourne un tableau contenant les infos pour le groupe</p>
* @access public
* @param entier identifiant de l'association NodeGroupUser
* @return tableau
*/
	function doLoadFromNodeId($id)
	{
		$tab=array();		# initialisation du retour
		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("node_id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_numrows()!=0)
		{
			# charge toutes les ligne
			for ($i=0; $i<$this->conn->sql_numrows(); $i++)
			{
				$tab[$i]=$this->conn->sql_fetchrow();
				$tab[$i]=$this->translateArray($tab[$i]);
			}
		}
		$this->conn->sql_freeresult();
		return $tab;
	}

/**
* doInsert : Insert la NodeGroupUser dans la BD
*<p>Insertion dans la Bd</p>
* @access public
* @param entier identifiant de l'utilisateur
* @param entier identifiant du groupe
* @param entier identifiant du noeud
* @return entier
*/
	function doInsert($userId, $groupId, $nodeId)
	{
		$sql="INSERT INTO ".$this->getTable()." ("
			.$this->getSqlName("user_id").", "
			.$this->getSqlName("group_id").", "
			.$this->getSqlName("node_id").") VALUES (";
		$sql.="".$userId.", ".$groupId.", ".$nodeId.")";

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_affectedrows()==0)
		{
			$systemError=1;
			$classe="NodeGroupUser";
			$message="Erreur dans NodeGroupUserManagerDb ";
			addError($systemError, $classe, $message, __line__, __file__);
			return 0;
		}
		$retour=$this->conn->sql_nextid();
		return $retour;
	}

/**
* doUpdate:Modifie la NodeGroupUser dans la BD
*<p>Mise à jour de la NodeGroupUser</p>
* @access public
* @param entier identifiant
* @param chaine libelle de la NodeGroupUser
* @param chaine repertoire de la NodeGroupUser
* @param chaine icone de la NodeGroupUser
* @param entier état de la NodeGroupUser (active ou inactive)
* @return booleen
*/
	function doUpdate($id, $userId, $groupId, $nodeId)
	{
		$sql="UPDATE ".$this->getTable()." SET "
			.$this->getSqlName("user_id")."=".$userId.", "
			.$this->getSqlName("group_id")."=".$groupId.", "
			.$this->getSqlName("node_id")."=".$nodeId." WHERE ";
		$sql.=$this->getSqlName("id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);
		$retour=$id;
		return $retour;
	}

/**
* doDelete:Detruit la NodeGroupUser dans la BD
*<p>Suppression de l'association Group/User/Node à partir de son identifiant</p>
* @access public
* @param entier identifiant
* @return booleen
*/
	function doDelete($id)
	{
		$sql="DELETE FROM ".$this->getTable()." WHERE ".$this->getSqlName("id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_affectedrows()==0)
		{
			$systemError=1;
			$classe="NodeGroupUser";
			$message="Erreur dans NodeGroupUserManagerDb ";
			addError($systemError, $classe, $message, __line__, __file__);
			return false;
		}
		return true;
	}

	//////////////////////////////////////////////////////////////////////////
	//
	// Utilitaires pour la gestion des compatibilités BD
	//
	/////////////////////////////////////////////////////////////////////////
/**
* translateKey : change les cles du tableau resultant d'une requete en tableau de données pour l'objet
*
* <p>Supprime le nom de la table dans les noms de champs renvoy?s par la BD<br/>
* garde la compatibilité avec les version précédentes</p>
* @param array tableau sql
* @access private
* @return array tableau des attributs
*/
	function translateArray($sqlArray)
	{
		/* Cas nouvelle BD systeme */
		$result["id"]				=$sqlArray[$this->getSqlName('id')];
		$result["group_id"]			=$sqlArray[$this->getSqlName("group_id")];
		$result["user_id"]			=$sqlArray[$this->getSqlName("user_id")];
		$result["node_id"]			=$sqlArray[$this->getSqlName("node_id")];
		return $result;
	}

/**
* initSqlAttributName : recupere le nom d'un attribut a partir d'une cle
*
* <p>En fonction de la version sql, on trouvera ici la correspondance entre le nom attribut de l'objet et son nom en BD<br/>
* cette methode permet de garder la compatibilité avec les version précédentes</p>
* @param chaine nom de l'attribut recherche
* @access private
* @return booleen
*/
	function initSqlAttribut()
	{
		if(defined('DATA_ACCES_TABLE_VERSION'))
		{
			if( DATA_ACCES_TABLE_VERSION == 1)
			{
				$this->sqlAttributArray["id"]				="node_group_user_id";
				$this->sqlAttributArray["group_id"]			="group_id";
				$this->sqlAttributArray["user_id"]			="user_id";
				$this->sqlAttributArray["node_id"]			="node_id";
				return true;
			}
		}
		$this->sqlAttributArray["id"]				="id";
		$this->sqlAttributArray["group_id"]			="group_id";
		$this->sqlAttributArray["user_id"]			="user_id";
		$this->sqlAttributArray["node_id"]			="node_id";
		return true;
	}

/**
* getSqlName : recupere le nom du champ a partir d'une cle
*
* <p>En fonction de la version sql, on trouvera ici la correspondance entre le nom attribut de l'objet et son nom en BD<br/>
* Cette methode permet de garder la compatibilite avec les version précédentes<br/>
* Elle s'appuie sur le tableau associatif $this->sqlAttributArray genere par initSqlAttributArray</p>
* @param chaine nom de l'attribut recherche
* @access private
* @return chaine nom du champ sql
*/
	function getSqlName($attribut)
	{
		return ( (isset($this->sqlAttributArray[$attribut]))?$this->sqlAttributArray[$attribut]:$attribut );
	}
}
?>
