<?php
/**------------------------------------------------
*
* Rooty, 2018 <rooty@rooty.me>
*
*
* This software is protected by copyright, please
* read the file COPYRIGHT.
* This program is distributed in the hope that it
* will be useful, but without any warranty; without
* even the implied warranty of merchantability or
* fitness for a particular purpose. Please
* read the file LICENCE.
*
* Fichier PermissionManager.php
*
* Ce fichier contient la classe PermissionManager
*
* @author Rooty <www.rooty.me|rooty@rooty.me>
* @link www.rooty.me
* @since 2004/04/14
* @version 0.3
* @package system_data
* @subpackage Permission
* @copyright Copyright &copy; 2009-2018, Rooty
*/

#####################################################################################################
################################# Parametrage
#####################################################################################################

/**
* declaration du system... si cette variable n'est pas définie, les fichier inclus ne marche pas...
* cette variable est déclarée sur la page d'execution du script.
* <p> if ( !defined('SYSTEM_IN') )
* {
* die("Hacking attempt");
* }</p>
*/
if ( !defined('SYSTEM_IN') )
{
 die("Hacking attempt");
}

/**
* Classe Permission
*/
require ($CONF_LIB_PATH."lib/system/system_data/permission/permission.php");

/**
* Classe PermissionManager
*
* Classe de gestion des Permissions<br>
* Classe d'abstraction permettant de gérer plusieurs configuration de ressources<br>
* Cette classe gère de plus le formatage des données (classe chaine et chiffre)<br>
* <br>
* Sont configuré dans /config/config.php:<br>
* - La Source d'information <br>
* -- actuellement seul DB possible->Pour ajouter une source reproduire FetchPermissionDB<br>
* -- et adapter le constructeur de PermissionManager<br>
* - Le Nom de la Table<br>
* - L'Permission par défaut<br>
* - La configuration (Paramétrage des sources de données) est faite dans lib/data_source/config_data_source.php<br>
*
* @package system_data
* @subpackage Permission
*/
class PermissionManager extends Manager
{

/**
* Constructeur de la classe PermissionManager PHP5
*
* @access public
*/
	function __construct()
	{
	}

/**
* LoadFromId: charge à partir d'un identifiant
*
* <p>Permet le récupération des infos d'un objet Permission à partir de son identifiant</p>
* <p>Retourne un tableau contenant les infos de l'objet<br>
* <br>ou faux si n'existe pas
* </p>
* @param identifiant de l'utilisateur
* @param tableau tableau des identifiants des groupes utilisateurs
* @param tableau tableau des noeuds disponilbes (accessible) pour l'utilisateur (optionnel)
* @access public
* @return tableau
*/
	function createInstance($id, $groupArray, $nodeAvailable="")
	{
		$tab=null;
		$nodeAvailable=(is_array($nodeAvailable))?$nodeAvailable:"";

		# On ajoute la gestion de cache
		if (DATA_ACCES_CACHE_PERMISSION==true)
			$tab=$this->LoadFromIdCache($id);

		# Cas l'enregistrement n'existe pas dans la cache
		if (!Is_object($tab))
		{
			$result=$GLOBALS["SYSTEM_MANAGER"]["RIGHT"]->getInstanceFromUserId($id, $groupArray, $nodeAvailable);
			
			$tab=new Permission();
			$tab->doLoad($id, $result);
			
			if (DATA_ACCES_CACHE_PERMISSION==true)
				$this->InsertCache($id, $tab);
		}
		return $tab;
	}

/**
* LoadFromCache: charge à partir d'un identifiant et dans le cahce
*
* <p>Affecte les champs de l'objet depuis la base et retourne vrai si tout est ok, faux sinon.</p>
* @param identifiant du TreeNode
* @access private
* @return tableau
*/
	function LoadFromIdCache($id)
	{
		$result=$GLOBALS["SYSTEM_MANAGER"]["PERMISSION_CACHE"]->createInstance($id);
		return $result->getData();
	}

/**
* Insertion de l'objet TreeNode.
* insere l'objet dans la base de données et retourne l'identifiant obtenu.
* @access private
* @return entier identifiant numérique
*/	
	function InsertCache($idCreation, $data)
	{
		$obj=$GLOBALS["SYSTEM_MANAGER"]["PERMISSION_CACHE"]->createNewInstance();
		$obj->doLoad($idCreation, $data);
		$this->CallSystemPlugin("__insertPermission", $obj);
		return $GLOBALS["SYSTEM_MANAGER"]["PERMISSION_CACHE"]->insertInstance($obj);
	}

/**
* Suppression du cache
* @access private
* @return entier identifiant numérique
*/	
	function DeleteCache($id)
	{
		$obj=$GLOBALS["SYSTEM_MANAGER"]["PERMISSION_CACHE"]->createNewInstance();
		$obj->doLoad($id, "");
		$this->CallSystemPlugin("__deletePermission", $obj);
		return $GLOBALS["SYSTEM_MANAGER"]["PERMISSION_CACHE"]->deleteInstance($obj);
	}
}
?>
