<?php

/**------------------------------------------------
*
* Rooty, 2018 <rooty@rooty.me>
*
*
* This software is protected by copyright, please
* read the file COPYRIGHT.
* This program is distributed in the hope that it
* will be useful, but without any warranty; without
* even the implied warranty of merchantability or
* fitness for a particular purpose. Please
* read the file LICENCE.
*
* Fichier RightManagerDb.php
*
* Ce fichier contient la classe RightManagerDb
*
* @author Rooty <www.rooty.me|rooty@rooty.me>
* @link www.rooty.me
* @since 2004/04/14
* @version 0.3
* @package system_data
* @subpackage Right
* @copyright Copyright &copy; 2009-2018, Rooty
*/

#####################################################################################################
################################# Parametrage
#####################################################################################################
/**
* declaration du system... si cette variable n'est pas définie, les fichier inclus ne marche pas...
* cette variable est déclarée sur la page d'execution du script.
* <p> if ( !defined('SYSTEM_IN') )
* {
* die("Hacking attempt");
* }</p>
*/
if ( !defined('SYSTEM_IN') )
{
 die("Hacking attempt");
}

/**
* Classe RightManagerDb
*
* classe de gestion des Rights pour une do de données database (type gérés par database)<br><br>
* Sont configuré dans config_data_acces.php:<br>
* - La do d'information <br>
*    (actuellement seul DB possible->Pour ajouter une do reproduire RightRightManagerDb)<br>
* - Le Nom de la Table<br>
* - La configuration (Paramétrage des dos de do de données) est faite dans config_data_do.php<br>
* - La declaration de la connexion est faite à partir de config_system.php
*
* @package system_data
* @subpackage Right
*/
class RightManagerDb extends RightManager
{

/**
* @var chaine
* @access private
* @desc ID de la Right
*/
var $table		= "";

/**
* @var object
* @access private
* @desc objet database
*/
var $conn		= null;

	//
	// Constructor
	//

/**
* Constructeur de la classe RightManagerDb PHP4
*
* <p>Initialise la RightManagerDb</p>
* @access public
*/
	function RightManagerDb()
	{
		$this->__construct();
	}

/**
* Constructeur de la classe RightManagerDb PHP5
*
* <p>Initialise la RightManagerDb</p>
* @access public
*/
	function __construct()
	{
		$this->setTable( DATA_ACCES_TABLE_RIGHT );	/* Appel à la constant correspondant */
		$this->initSqlAttribut();			/* initialisation des noms de champs */
		$this->setConn($GLOBALS['SYSTEM_DATABASE_CONN']);
	}

/**
* getTable : recupere le nom de la table utilisée
* @access public
* @return chaine
*/
	function getTable()
	{
		return $this->table;
	}

/**
* setTable : recupere le nom de la table utilisée
* @access public
* @param chaine nom de la table
* @return chaine
*/
	function setTable($chaine)
	{
		if (!is_string($chaine))
			return false;

		$this->table=$chaine;
		return true;
	}

/**
* getTable : recupere le nom de la table utilisée
* @access public
* @return chaine
*/
	function getConn()
	{
		return $this->conn;
	}

/**
* setTable : recupere le nom de la table utilisée
* @access public
* @param object objet classe "database"
* @return chaine
*/
	function setConn(&$obj)
	{
		if (!is_object($obj))
			return false;

		$this->conn=&$obj;
		return true;
	}

/**
* doLoadFromId: Charge le droit depuis la BD
*
* <p>Retourne un tableau contenant les infos de l'objets
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </p>
* @access public
* @param entier identifiant du droit
* @return tableau
*/
	function doLoadFromId($id)
	{
		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_numrows()==0)
		{
			$systemErro=1;
			$classe="Right";
			$message="Erreur dans RightManagerDb ";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}
		$tab=$this->conn->sql_fetchrow();
		$tab=$this->translateArray($tab);

		# Destruction des éléments
		$this->conn->sql_freeresult();					# Libération Mémoire
		return $tab;
	}

/**
* doInsert: Insert le droit dans la BD
*
* <p>Insertion dans la Bd</p>
* @param chaine nom de la classe concernée
* @param chaine nom de la methode concernée
* @param entier identifiant de l'objet
* @param entier identifiant du noeud
* @param booleen si l'objet à des droits recursifs ou non?!
* @param entier identifiant utilisateur
* @param entier identifiant du groupe utilisateur
* @param booleen est un droit d'entrée
*
* @access public
* @return entier
*/
	function doInsert($className, $methodName, $objectId, $noeudId, $userId, $groupId)
	{
		$sql="INSERT INTO ".$this->getTable()." ("
			.$this->getSqlName("class_name").", "
			.$this->getSqlName("method_name").", "
			.$this->getSqlName("object_id").", "
			.$this->getSqlName("node_id,user_id").", "
			.$this->getSqlName("group_id").") VALUES (";
		$sql.="'".$className."', '".$methodName."', ".$objectId.", ".$noeudId.", ".$userId.", ".$groupId.")";

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_affectedrows()==0)
		{
			$systemErro=1;
			$classe="Right";
			$message="Erreur dans RightManagerDb ";
			addError($systemError,$classe,$message, __line__, __file__);
			return 0;
		}
		$retour=$this->conn->sql_nextid();
		return $retour;
	}

/**
* doUpdate:Modifie le droit dans la BD
*
* <p>Mise à jour du droit</p>
* @param entier identifiant
* @param chaine libelle du droit
* @param chaine repertoire du droit
* @param chaine icone du droit
* @param entier état du droit (active ou inactive)
*
* @access public
* @return booleen
*/
	function doUpdate($id, $className, $methodName, $objectId, $noeudId, $userId, $groupId)
	{
		$sql ="UPDATE ".$this->getTable()." SET "
			.$this->getSqlName("class_name")."='".$class_name."', "
			.$this->getSqlName("method_name")."='".$method_name."', "
			.$this->getSqlName("object_id")."=".$objectId.", "
			.$this->getSqlName("node_id")."=".$noeudId.", "
			.$this->getSqlName("user_id")."=".$userId.", "
			.$this->getSqlName("group_id")."=".$groupId." WHERE ";
		$sql.=$this->getSqlName("id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);
		$retour=$id;
		return $retour;
	}

/**
* doDelete : Detruit le droit dans la BD
*
* <p>Suppression de le droit à partir de son identifiant</p>
* @param entier identifiant
* @access public
* @return booleen
*/
	function doDelete($id)
	{
		$sql="DELETE FROM ".$this->getTable()." WHERE ".$this->getSqlName("id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_affectedrows()==0)
		{
			$systemErro=1;
			$classe="Right";
			$message="Erreur dans RightManagerDb ";
			addError($systemError,$classe,$message, __line__, __file__);
			return false;
		}
		return true;
	}

/**
* doLoadPermission : Charge les droits depuis la BD
*
* <p>Retourne un tableau contenant les infos de l'objets
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </p>
* @access public
* @param entier identifiant du droit
* @param tableau tableau des groupes de l'utilisateur
* @param tableau tableau des noeuds disponilbes (accessible) pour l'utilisateur (optionnel)
* @return tableau
*/
	function doLoadPermission($id, $groupAvailable, $nodeAvailable)
	{
		$optGroup="";
		$optNode="";

		# Génération des option pour les informations...
		if(count($groupAvailable)>0)
		{
			$optGroup=" OR (".$this->getSqlName("group_id")." IN (".implode(",", $groupAvailable).") )";
		}

		if(count($nodeAvailable)>0)
		{
			$optNode=" AND (".$this->getSqlName("node_id")." IN (".implode(",", $nodeAvailable).") )";
		}

		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("user_id")."=".$id.$optGroup.$optNode;

		# Requete
		$result=$this->conn->sql_query($sql);
		$tab=array();

		while($right=$this->conn->sql_fetchrow())
		{
			$tab[]=$this->translateArray($right);
		}

		# Destruction des éléments
		$this->conn->sql_freeresult();					# Libération Mémoire
		return $tab;
	}

/**
* doLoadFromNodeId : Charge les droits depuis la BD
*
* <p>Retourne un tableau contenant les infos de l'objets
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </p>
* @access public
* @param entier identifiant du droit
* @param tableau tableau des groupes de l'utilisateur
* @return tableau
*/
	function doLoadFromNodeId($id)
	{
		if (!Is_numeric($id))
		{
			$systemErro=1;
			$classe="Right";
			$message="Erreur dans RightManagerDb ";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}
		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("node_id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);
		$tab=array();

		for ($i=0; $i<$this->conn->sql_numrows(); $i++)
		{
			$tab[$i]=$this->conn->sql_fetchrow();
			$tab[$i]=$this->translateArray($tab[$i]);
		}

		# Destruction des éléments
		$this->conn->sql_freeresult();					# Libération Mémoire
		return $tab;
	}

/**
* doLoadFromNodeId : Charge les droits depuis la BD
*
* <p>Retourne un tableau contenant les infos de l'objets
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </p>
* @access public
* @param entier identifiant du droit
* @param tableau tableau des groupes de l'utilisateur
* @return tableau
*/
	function doLoadFromGroupId($id)
	{
		if (!Is_numeric($id))
		{
			$systemErro=1;
			$classe="Right";
			$message="Erreur dans RightManagerDb ";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}
		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("group_id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);
		$tab=array();

		for ($i=0; $i<$this->conn->sql_numrows(); $i++)
		{
			$tab[$i]=$this->conn->sql_fetchrow();
			$tab[$i]=$this->translateArray($tab[$i]);
		}

		# Destruction des éléments
		$this->conn->sql_freeresult();					# Libération Mémoire
		return $tab;
	}

/**
* doLoadFromNodeId : Charge les droits depuis la BD
*
* <p>Retourne un tableau contenant les infos de l'objets
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </p>
* @access public
* @param entier identifiant du droit
* @param tableau tableau des groupes de l'utilisateur
* @return tableau
*/
	function doLoadFromObjectId($id)
	{
		if (!Is_numeric($id))
		{
			$systemErro=1;
			$classe="Right";
			$message="Erreur dans RightManagerDb ";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}
		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("object_id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);
		$tab=array();

		for ($i=0; $i<$this->conn->sql_numrows(); $i++)
		{
			$tab[$i]=$this->conn->sql_fetchrow();
			$tab[$i]=$this->translateArray($tab[$i]);
		}

		# Destruction des éléments
		$this->conn->sql_freeresult();					# Libération Mémoire
		return $tab;
	}

	//////////////////////////////////////////////////////////////////////////
	//
	// Utilitaires pour la gestion des compatibilités BD
	//
	/////////////////////////////////////////////////////////////////////////
/**
* translateKey : change les cles du tableau resultant d'une requete en tableau de données pour l'objet
*
* <p>Supprime le nom de la table dans les noms de champs renvoy?s par la BD<br/>
* garde la compatibilité avec les version précédentes</p>
* @param array tableau sql
* @access private
* @return array tableau des attributs
*/
	function translateArray($sqlArray)
	{
		/* Cas nouvelle BD systeme */
		$result["id"]				=$sqlArray[$this->getSqlName('id')];
		$result["group_id"]			=$sqlArray[$this->getSqlName("group_id")];
		$result["user_id"]			=$sqlArray[$this->getSqlName("user_id")];
		$result["node_id"]			=$sqlArray[$this->getSqlName("node_id")];
		$result["class_name"]			=$sqlArray[$this->getSqlName("class_name")];
		$result["method_name"]			=$sqlArray[$this->getSqlName("method_name")];
		$result["object_id"]			=$sqlArray[$this->getSqlName("object_id")];
		return $result;
	}

/**
* initSqlAttributName : recupere le nom d'un attribut a partir d'une cle
*
* <p>En fonction de la version sql, on trouvera ici la correspondance entre le nom attribut de l'objet et son nom en BD<br/>
* cette methode permet de garder la compatibilité avec les version précédentes</p>
* @param chaine nom de l'attribut recherche
* @access private
* @return booleen
*/
	function initSqlAttribut()
	{
		if(defined('DATA_ACCES_TABLE_VERSION'))
		{
			if( DATA_ACCES_TABLE_VERSION == 1)
			{
				$this->sqlAttributArray["id"]				="right_id";
				$this->sqlAttributArray["group_id"]			="group_id";
				$this->sqlAttributArray["user_id"]			="user_id";
				$this->sqlAttributArray["node_id"]			="node_id";
				$this->sqlAttributArray["object_id"]			="coordination_object_id";
				$this->sqlAttributArray["class_name"]			="coordination_object_content_type";
				$this->sqlAttributArray["method_name"]			="right_method_name";
				return true;
			}
		}
		$this->sqlAttributArray["id"]				="id";
		$this->sqlAttributArray["group_id"]			="group_id";
		$this->sqlAttributArray["user_id"]			="user_id";
		$this->sqlAttributArray["node_id"]			="node_id";
		$this->sqlAttributArray["object_id"]			="object_id";
		$this->sqlAttributArray["class_name"]			="class_name";
		$this->sqlAttributArray["method_name"]			="method_name";
		return true;
	}

/**
* getSqlName : recupere le nom du champ a partir d'une cle
*
* <p>En fonction de la version sql, on trouvera ici la correspondance entre le nom attribut de l'objet et son nom en BD<br/>
* Cette methode permet de garder la compatibilite avec les version précédentes<br/>
* Elle s'appuie sur le tableau associatif $this->sqlAttributArray genere par initSqlAttributArray</p>
* @param chaine nom de l'attribut recherche
* @access private
* @return chaine nom du champ sql
*/
	function getSqlName($attribut)
	{
		return ( (isset($this->sqlAttributArray[$attribut]))?$this->sqlAttributArray[$attribut]:$attribut );
	}
}
?>
