<?php
/**------------------------------------------------
*
* Rooty, 2018 <rooty@rooty.me>
*
*
* This software is protected by copyright, please
* read the file COPYRIGHT.
* This program is distributed in the hope that it
* will be useful, but without any warranty; without
* even the implied warranty of merchantability or
* fitness for a particular purpose. Please
* read the file LICENCE.
*
* Fichier UserPreferenceManager.php
*
* Ce fichier contient la classe UserPreferenceManager
*
* @author Rooty <www.rooty.me|rooty@rooty.me>
* @link www.rooty.me
* @since 2004/06/05
* @version 0.3
* @package system_data
* @subpackage UserPreference
* @copyright Copyright &copy; 2009-2018, Rooty
*/

#####################################################################################################
################################# Parametrage
#####################################################################################################

/**
* declaration du system... si cette variable n'est pas définie, les fichier inclus ne marche pas...
* cette variable est déclarée sur la page d'execution du script.
* <p> if ( !defined('SYSTEM_IN') )
* {
* die("Hacking attempt");
* }</p>
*/
if ( !defined('SYSTEM_IN') )
{
 die("Hacking attempt");
}

/**
* Appel à la classe UserPreference...
*/
require ($CONF_LIB_PATH."lib/system/system_data/userpreference/userpreference.php");

/**
* Classe UserPreferenceManager
* 
* <p>Classe de gestion des instances de UserPreferences <br>
*   (permet de fabriquer, detruire, mettre à jour des objet UserPreferences)<br>
* Cette classe se sert des ressources à sa disposition (dans ./ressource)<br>
* Les Classes de ressource doivent avoir toutes les methodes correspondantes <br>
* aux methodes de la classe intitulés sourceXXX</p>
* 
* <p>Est configuré dans data_acces.php : <br>
* - La Source d'information (Db)<br>
* l'objet ressource se sert lui-même des classes d'accés aux données(lib/data_source/...)<br>
* </p>
* @package system_data
* @subpackage UserPreference
*/
class UserPreferenceManager extends Manager
{

	//
	// Constructor
	//
/**
* Constructeur de la classe UserPreferenceManager PHP5
*
* @access public
*/
	function __construct()
	{
	}


###########################################################################
#### Méthodes abstraites
###########################################################################

/**
* doLoadId: Charge la UserPreference depuis la BD
*
* <p>Retourne un tableau contenant les infos de l'objets
* <br>ou faux si n'existe pas;<br>
* Précondition : id doit être un entier
* </p>
* @access public
* @abstract
* @param entier identifiant de l'association UserPreference
* @return tableau
*/
	function doLoadFromId($id)
	{
		return array();
	}

/**
* doInsert: Insert la UserPreference dans la BD
*
* <P>Insertion dans la Bd</P>
* @param entier identifiant de l'utilisateur
* @param entier identifiant du groupe
* @param booleen is node only
* @param booleen is forbidden
* @abstract
* @access public
* @return entier
*/
	function doInsert($langueId, $entryNodeId, $rightId)
	{
		return 0;
	}

/**
* doUpdate:Modifie la UserPreference dans la BD
*
* <P>Mise à jour de la UserPreference</P>
* @param entier identifiant de l'association
* @param entier identifiant de l'utilisateur
* @param entier identifiant du groupe
* @param booleen is node only
* @param booleen is forbidden
* @access public 
* @abstract
* @return booleen
*/
	function doUpdate($id, $langueId, $entryNodeId, $rightId)
	{
		return 0;
	}

/**
* doDelete : Detruit le UserPreference dans la BD
*
* <P>Suppression de l'association Group et User à partir de son identifiant</P>
* @param entier identifiant
* @abstract
* @access public
* @return booleen
*/
	function doDelete($id)
	{
		return true;
	}

/**
* sourceLoadFromUserId : charge à partir d'un identifiant utilisateur
*
* <p>Permet le récupération des infos d'un objet UserPreference à partir de son identifiant</p>
* <p>Retourne un tableau contenant les infos de l'objets<br>
* <br>ou faux si n'existe pas
* </p>
* @param identifiant de l'association UserPreference
* @access private
* @return tableau
*/
	function sourceLoadFromId($id)
	{
		$tab=$this->doLoadFromId($id);
		# Gestion d'un tableau intermediaire avec la reprise des elements
		return $tab;
	}


/**
* sourceInsert : Insert la UserPreference
* 
* <p>Insertion de l'objet UserPreference dans la source de données<br>
* indifférement du type de cette source</p>
* <p>Retourne L'identifiant de l'objet insérer</p>
* @param entier identifiant de la langue
* @param entier identifiant du noeud d'entree
* @param entier identifiant du droit par défaut pour le noeud d'entrée
* @access private
* @return entier
*/
	function sourceInsert($langueId, $entryNodeId, $rightId)
	{
		return $this->doInsert($langueId, $entryNodeId, $rightId);
	}

/**
* sourceUpdateFromParam : Met à jour la UserPreference
*
* <p>Mise à jour de l'objet indifferemment de la source de données</p>
* @param entier identifiant
* @param entier identifiant de la langue
* @param entier identifiant du noeud d'entree
* @param entier identifiant du droit par défaut pour le noeud d'entrée
* @access private
* @return booleen
*/
	function sourceUpdate($id, $langueId, $entryNodeId, $rightId)
	{
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if (!Is_numeric($id))
		{
			$systemError=1;
			$classe="userpreference";
			$message="Erreur de Modification dans UserPreferenceManager avec l'id ".$id;
			addError($systemError, $classe, $message, __line__, __file__);
			return false;			
		}
		return $this->doUpdate($id, $langueId, $entryNodeId, $rightId);
	}

/**
* sourceDeleteFromId : Detruit la UserPreference
*
*<p>Suppression de l'objet à partir de son identifiant</p>
* @param entier identifiant de l'association UserPreference
* @access private
* @return booleen
*/
	function sourceDeleteFromId($id)
	{
		if (!Is_numeric($id))
		{
			$systemError=2;

			$classe="userpreference";
			$message="Erreur de SUPRESSION dans UserPreferenceManager avec l'id ".$id;
			addError($systemError,$classe,$message, __line__, __file__);
			return false;
		}

		return $this->doDelete($id);
	}

/**
* createNewInstance : créer un objet vierge
*
* @access public
* @return object
*/
	function createNewInstance()
	{
		return new UserPreference();
	}

/**
* createInstance : récupere l'objet avec l'identifiant $id
*
* @param entier identifiant de l'association UserPreference
* @access public 
* @return object retourne un objet de type UserPreference
*/
	function createInstance($id)
	{
		$return = new UserPreference();
		if (is_numeric($id))
		{
			/* Récupération des infos */
			$tab=$this->sourceLoadFromId($id);
			if (is_array($tab) && isset($tab["id"]) && is_numeric($tab["id"]))
			{
				/* création et alimentation de l'objet */
				$return->doLoad($tab["id"], $tab["langue_id"], $tab["entry_node_id"], $tab["right_id"]);
			}
			return $return;
		}else{
			$systemError=3;
			$classe="UserPreferenceManager";
			$message="Erreur id invalide ".$id;
			addError($systemError, $classe, $message, __line__, __file__);
		}
		return $return;
	}
/**
* deleteInstance : detruit l'objet physique
*
* @param object objet UserPreference à effacer
* @access public 
* @return object objetUserPreference mis à jour
*/
	function deleteInstance($obj)
	{
		$return = false;
		if ((strtolower(get_class($obj))=="userpreference") )
		{
			if($obj->isLoaded()==true)
			{
				/* Récupération des infos */
				$this->CallSystemPlugin("__deleteUserPreference", $obj);
				$return=$this->sourceDeleteFromId($obj->getId());
				$obj->setId(0);
				return $obj;
			}
		}
		/* Erreur */
		$systemError=3;
		$classe="UserPreferenceManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}

/**
* updateInstance : met à jour l'objet
*
* @param object objet UserPreference à modifier
* @access public 
* @return object objetUserPreference mis à jour
*/
	function updateInstance($obj)
	{
		$return = false;
		if ((strtolower(get_class($obj))=="userpreference") && ($obj->isLoaded()==true))
		{
			/* Récupération des infos */
			$id=$this->sourceUpdate($obj->getId(), $obj->getLangueId(), $obj->getEntryNodeId(), $obj->getRightId);
			$this->CallSystemPlugin("__updateUserPreference", $obj);
			return $obj;
		}
		/* Erreur */
		$systemError=3;
		$classe="UserPreferenceManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}
/**
* insertInstance : créer enregistre l'objet
*
* <p>affecte l'id de l'objet si nécessaire</p>
* @param object objet UserPreference à inserer
* @access public 
* @return object objetUserPreference mis à jour
*/
	function insertInstance($obj)
	{
		if ((strtolower(get_class($obj))=="userpreference"))
		{
			if ($obj->isLoaded()==false)
			{
				/* Récupération des infos */
				$id=$this->sourceInsert($obj->getLangueId(), $obj->getEntryNodeId(), $obj->getRightId);
				$obj->setId($id);
				$this->CallSystemPlugin("__insertUserPreference", $obj);
				return $obj;
			}
		}
		/* Erreur */
		$systemError=3;
		$classe="UserPreferenceManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}
/**
* saveInstance : créer enregistre l'objet
*
* @param object objet UserPreference à sauvegarder
* @access public 
* @return object objetUserPreference mis à jour
*/
	function saveInstance($obj)
	{
		if ((strtolower(get_class($obj))=="userpreference"))
		{
			if ($obj->isLoaded()==false)
			{
				$return=$this->insertInstance($obj);
			}else{
				$return=$this->updateInstance($obj);
			}
			return $return;
		}
		/* Erreur */

		$systemError=3;
		$classe="UserPreferenceManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		$return=$obj;

		return $return;
	}
}
?>
