<?php

/**------------------------------------------------
*
* Rooty, 2018 <rooty@rooty.me>
*
*
* This software is protected by copyright, please
* read the file COPYRIGHT.
* This program is distributed in the hope that it
* will be useful, but without any warranty; without
* even the implied warranty of merchantability or
* fitness for a particular purpose. Please
* read the file LICENCE.
*
* Fichier UserSessionManagerDb.php
*
* Ce fichier contient la classe UserSessionManagerDb
*
* @author Initiance <www.initiance.com|olivier@initiance.com & Christophe HEURTAUX>
* @link www.rooty.me
* @since 2004/04/14
* @version 0.3
* @package system_data
* @subpackage UserSession
* @copyright Copyright &copy; 2009-2018, Rooty
*/

#####################################################################################################
################################# Parametrage
#####################################################################################################
/**
* declaration du system... si cette variable n'est pas définie, les fichier inclus ne marche pas...
* cette variable est déclarée sur la page d'execution du script.
* <p> if ( !defined('SYSTEM_IN') )
* {
* die("Hacking attempt");
* }</p>
*/
if ( !defined('SYSTEM_IN') )
{
 die("Hacking attempt");
}

/**
* Classe UserSessionManagerDb
*
* classe de gestion des UserSessions pour une do de données database (type gérés par database)<br><br>
* Sont configuré dans config_data_acces.php:<br>
* - La do d'information <br>
*    (actuellement seul DB possible->Pour ajouter une do reproduire NodeUserSessionManagerDb)<br>
* - Le Nom de la Table<br>
* - La configuration (Paramétrage des dos de do de données) est faite dans config_data_do.php<br>
* - La declaration de la connexion est faite à partir de config_system.php
*
* @package system_data
* @subpackage UserSession
*/
class UserSessionManagerDb extends UserSessionManager
{

/**
* @var chaine
* @access private
* @desc ID de la UserSession
*/
var $table		= "";

/**
* @var object
* @access private
* @desc objet database
*/
var $conn		= null;

	//
	// Constructor
	//

/**
*Constructeur de la classe UserSessionManagerDb
*<p>Initialise la UserSessionManagerDb</p>
* @access public
*/
	function UserSessionManagerDb()
	{
		$this->__construct();
	}

	function __construct()
	{
		$this->setTable( DATA_ACCES_TABLE_USER_SESSION );	/* Appel à la constant correspondant */
		$this->initSqlAttribut();				/* initialisation des noms de champs */
		$this->setConn($GLOBALS['SYSTEM_DATABASE_CONN']);
	}

/**
* getTable : recupere le nom de la table utilisée
* @access public
* @return chaine
*/
	function getTable()
	{
		return $this->table;
	}

/**
* setTable : recupere le nom de la table utilisée
* @access public
* @param chaine nom de la table
* @return chaine
*/
	function setTable($chaine)
	{
		if (!is_string($chaine))
			return false;

		$this->table=$chaine;
		return true;
	}

/**
* getTable : recupere le nom de la table utilisée
* @access public
* @return chaine
*/
	function getConn()
	{
		return $this->conn;
	}

/**
* setTable : recupere le nom de la table utilisée
* @access public
* @param object objet classe "database"
* @return chaine
*/
	function setConn(&$obj)
	{
		if (!is_object($obj))
			return false;

		$this->conn=&$obj;
		return true;
	}

/**
* doLoadFromId: Charge la UserSession depuis la BD
*
* <p>Retourne un tableau contenant les infos de l'objets
* </p>
* @access public
* @param entier identifiant de l'association UserSession
* @return tableau
*/
	function doLoadFromId($id)
	{
		$sql="SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("id")."='".$id."'";

		# Requete
		$tab=array();
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_numrows()!=0)
		{
			$tab=$this->conn->sql_fetchrow();
			$tab=$this->translateArray($tab);
		}

		# Destruction des éléments
		$this->conn->sql_freeresult();					# Libération Mémoire

		return $tab;
	}

/**
* doInsert: Insert la UserSession dans la BD
*
* <P>Insertion dans la Bd</P>
* @param entier identifiant de l'utilisateur
* @param entier identifiant du groupe
* @access public
* @return entier
*/
	function doInsert($id, $user, $userPreference, $langue, $ip, $entryNodeId, $navigationNodeId, $session_begin, $lastAction, $url, $session_vars="")
	{
		$sql="INSERT INTO ".$this->getTable()." ("
			.$this->getSqlName("id").", "
			.$this->getSqlName("user_obj").", "
			.$this->getSqlName("user_preference").", "
			.$this->getSqlName("langue").", "
			.$this->getSqlName("ip").", "
			.$this->getSqlName("session_begin").", "
			.$this->getSqlName("last_action").", "
			.$this->getSqlName("entry_node_id").", "
			.$this->getSqlName("navigation_node_id").", "
			.$this->getSqlName("url").", "
			.$this->getSqlName("session_vars").") VALUES (";

			$sql.="'".$id."', '".$user."', '".$userPreference."', '".$langue."', '".$ip."', ".$session_begin.", ".$lastAction.", ".$entryNodeId.", ".$navigationNodeId.", '".$url."', '".$session_vars."')";

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_affectedrows()==0)
		{
			$systemError=1;
			$classe="UserSession";
			$message="Erreur dans UserSessionManagerDb";
			addError($systemError,$classe,$message, __line__, __file__);
			return 0;
		}
		$retour=$id;
		return $retour;
	}

/**
* doUpdate:Modifie la UserSession dans la BD
*
* <P>Mise à jour de la UserSession</P>
* @param entier identifiant de l'association
* @param entier identifiant de l'utilisateur
* @param entier identifiant du groupe
* @access public
* @return booleen
*/
	function doUpdate($id, $user, $userPreference, $langue, $ip, $entryNodeId, $navigationNodeId, $session_begin, $lastAction, $url, $session_vars="")
	{
		$sql="UPDATE ".$this->getTable()." SET "
			.$this->getSqlName("user_obj")."='".$user."', "
			.$this->getSqlName("user_preference")."='".$userPreference."', "
			.$this->getSqlName("langue")."='".$langue."', "
			.$this->getSqlName("ip")."='".$ip."', "
			.$this->getSqlName("session_begin")."=".$session_begin.", "
			.$this->getSqlName("last_action")."=".$lastAction.", "
			.$this->getSqlName("entry_node_id")."=".$entryNodeId.", "
			.$this->getSqlName("navigation_node_id")."='".$navigationNodeId."', "
			.$this->getSqlName("url")."='".$url."', "
			.$this->getSqlName("session_vars")."='".$session_vars."' WHERE ";

			$sql.="".$this->getSqlName("id")."='".$id."'";

		# Requete
		$result=$this->conn->sql_query($sql);
		$retour=$id;

		return $retour;
	}

/**
* doDelete : Detruit le UserSession dans la BD
*
* @param entier identifiant
* @access public
* @return booleen
*/
	function doDelete($id)
	{
		$sql="DELETE FROM ".$this->getTable()." WHERE ".$this->getSqlName("id")."='".$id."'";

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_affectedrows()==0)
		{
			$systemError=1;
			$classe="UserSession";
			$message="Erreur de SUPPRESSION dans UserSessionManagerDb";
			addError($systemError,$classe,$message, __line__, __file__);

			return false;
		}
		return true;
	}

/**
* doClean : Detruit les users sessions dont le délai est dépassé
*
* @param entier identifiant
* @access public
* @return booleen
*/
	function doClean( $time )
	{
		$timeToLive=time()-$time;
		$sql="DELETE FROM ".$this->getTable()." WHERE ".$this->getSqlName("last_action")."<=".$timeToLive."";

		# Requete
		$result=$this->conn->sql_query($sql);

		return true;
	}

	//////////////////////////////////////////////////////////////////////////
	//
	// Utilitaires pour la gestion des compatibilités BD
	//
	/////////////////////////////////////////////////////////////////////////
/**
* translateKey : change les cles du tableau resultant d'une requete en tableau de données pour l'objet
*
* <p>Supprime le nom de la table dans les noms de champs renvoyés par la BD<br/>
* garde la compatibilité avec les version précédentes</p>
* @param array tableau sql
* @access private
* @return array tableau des attributs
*/
	function translateArray($sqlArray)
	{
		/* Cas nouvelle BD systeme */
		$result["id"]				=$sqlArray[$this->getSqlName('id')];
		$result["user_obj"]			=$sqlArray[$this->getSqlName("user_obj")];
		$result["user_preference"]		=$sqlArray[$this->getSqlName("user_preference")];
		$result["langue"]			=$sqlArray[$this->getSqlName("langue")];
		$result["ip"]				=$sqlArray[$this->getSqlName("ip")];
		$result["session_begin"]		=$sqlArray[$this->getSqlName("session_begin")];
		$result["last_action"]			=$sqlArray[$this->getSqlName("last_action")];
		$result["entry_node_id"]		=$sqlArray[$this->getSqlName("entry_node_id")];
		$result["navigation_node_id"]		=$sqlArray[$this->getSqlName("navigation_node_id")];
		$result["url"]				=$sqlArray[$this->getSqlName("url")];
		$result["session_vars"]			=$sqlArray[$this->getSqlName("session_vars")];

		return $result;
	}

/**
* initSqlAttributName : recupere le nom d'un attribut a partir d'une cle
*
* <p>En fonction de la version sql, on trouvera ici la correspondance entre le nom attribut de l'objet et son nom en BD<br/>
* cette methode permet de garder la compatibilité avec les version précédentes</p>
* @param chaine nom de l'attribut recherche
* @access private
* @return booleen
*/
	function initSqlAttribut()
	{
		if(defined('DATA_ACCES_TABLE_VERSION'))
		{
			if( DATA_ACCES_TABLE_VERSION == 1)
			{
				$this->sqlAttributArray["id"]				="user_session_id";
				$this->sqlAttributArray["user_obj"]			="user_object";
				$this->sqlAttributArray["langue"]			="language_object";
				$this->sqlAttributArray["user_preference"]		="user_preference_object";
				$this->sqlAttributArray["ip"]				="user_session_ip";
				$this->sqlAttributArray["session_begin"]		="user_session_begin";
				$this->sqlAttributArray["last_action"]			="user_session_last_action";
				$this->sqlAttributArray["entry_node_id"]		="user_session_entry_node_id";
				$this->sqlAttributArray["navigation_node_id"]		="user_session_navigation_node_id";
				$this->sqlAttributArray["url"]				="user_session_url";
				$this->sqlAttributArray["session_vars"]			="user_session_vars";

				return true;
			}
		}
		$this->sqlAttributArray["id"]				="id";
		$this->sqlAttributArray["user_obj"]			="user_obj";
		$this->sqlAttributArray["langue"]			="langue";
		$this->sqlAttributArray["user_preference"]		="user_preference";
		$this->sqlAttributArray["ip"]				="ip";
		$this->sqlAttributArray["session_begin"]		="session_begin";
		$this->sqlAttributArray["last_action"]			="last_action";
		$this->sqlAttributArray["entry_node_id"]		="entry_node_id";
		$this->sqlAttributArray["navigation_node_id"]		="navigation_node_id";
		$this->sqlAttributArray["url"]				="url";
		$this->sqlAttributArray["session_vars"]			="session_vars";

		return true;
	}

/**
* getSqlName : recupere le nom du champ a partir d'une cle
*
* <p>En fonction de la version sql, on trouvera ici la correspondance entre le nom attribut de l'objet et son nom en BD<br/>
* Cette methode permet de garder la compatibilite avec les version précédentes<br/>
* Elle s'appuie sur le tableau associatif $this->sqlAttributArray genere par initSqlAttributArray</p>
* @param chaine nom de l'attribut recherche
* @access private
* @return chaine nom du champ sql
*/
	function getSqlName($attribut)
	{
		return ( (isset($this->sqlAttributArray[$attribut]))?$this->sqlAttributArray[$attribut]:$attribut );
	}
}
?>
